@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: analysis.c,v 1.239 2013/07/18 02:01:23 mdpetch Exp $
+ * $Id: analysis.c,v 1.242 2015/03/01 13:14:20 plm Exp $
  */
 
 #include "config.h"
@@ -32,7 +32,6 @@
 #include "gtkgame.h"
 #endif
 #include "positionid.h"
-#include "rollout.h"
 #include "analysis.h"
 #include "sound.h"
 #include "matchequity.h"
@@ -87,7 +86,7 @@ GetRating(const float rError)
 }
 
 static float
-LuckFirst(const TanBoard anBoard, const int n0, const int n1, const cubeinfo * pci, const evalcontext * pec)
+LuckFirst(const TanBoard anBoard, const int n0, const int n1, cubeinfo * pci, const evalcontext * pec)
 {
 
     TanBoard anBoardTemp;
@@ -107,14 +106,14 @@ LuckFirst(const TanBoard anBoard, const int n0, const int n1, const cubeinfo * p
 
             /* Find the best move for each roll at ply 0 only. */
             if (FindnSaveBestMoves(&ml, i + 1, j + 1, (ConstTanBoard) anBoardTemp, NULL, 0.0f,
-                                   (cubeinfo *) pci, (evalcontext *) pec, defaultFilters) < 0)
+                                   pci, pec, defaultFilters) < 0)
                 return (float) ERR_VAL;
 
             if (!ml.cMoves) {
 
                 SwapSides(anBoardTemp);
 
-                if (GeneralEvaluationE(ar, (ConstTanBoard) anBoardTemp, &ciOpp, (evalcontext *) pec) < 0)
+                if (GeneralEvaluationE(ar, (ConstTanBoard) anBoardTemp, &ciOpp, pec) < 0)
                     return (float) ERR_VAL;
 
                 if (pec->fCubeful) {
@@ -143,14 +142,14 @@ LuckFirst(const TanBoard anBoard, const int n0, const int n1, const cubeinfo * p
 
             /* Find the best move for each roll at ply 0 only. */
             if (FindnSaveBestMoves(&ml, i + 1, j + 1, (ConstTanBoard) anBoardTemp, NULL, 0.0f,
-                                   &ciOpp, (evalcontext *) pec, defaultFilters) < 0)
+                                   &ciOpp, pec, defaultFilters) < 0)
                 return (float) ERR_VAL;
 
             if (!ml.cMoves) {
 
                 SwapSides(anBoardTemp);
 
-                if (GeneralEvaluationE(ar, (ConstTanBoard) anBoardTemp, (cubeinfo *) pci, (evalcontext *) pec) < 0)
+                if (GeneralEvaluationE(ar, (ConstTanBoard) anBoardTemp, pci, pec) < 0)
                     return (float) ERR_VAL;
 
                 if (pec->fCubeful) {
@@ -196,14 +195,14 @@ LuckNormal(const TanBoard anBoard, const int n0, const int n1, const cubeinfo *
 
             /* Find the best move for each roll at ply 0 only. */
             if (FindnSaveBestMoves(&ml, i + 1, j + 1, (ConstTanBoard) anBoardTemp, NULL, 0.0f,
-                                   (cubeinfo *) pci, (evalcontext *) pec, defaultFilters) < 0)
+                                   pci, pec, defaultFilters) < 0)
                 return (float) ERR_VAL;
 
             if (!ml.cMoves) {
 
                 SwapSides(anBoardTemp);
 
-                if (GeneralEvaluationE(ar, (ConstTanBoard) anBoardTemp, &ciOpp, (evalcontext *) pec) < 0)
+                if (GeneralEvaluationE(ar, (ConstTanBoard) anBoardTemp, &ciOpp, pec) < 0)
                     return (float) ERR_VAL;
 
                 if (pec->fCubeful) {
@@ -238,10 +237,10 @@ LuckAnalysis(const TanBoard anBoard, int n0, int n1, matchstate * pms)
     InitBoard(init_board, pms->bgv);
     is_init_board = !memcmp(init_board, pms->anBoard, 2 * 25 * sizeof(int));
 
-    if (n0-- < n1--)
+    if (n0-- < n1--)            /* -- because as input n0 and n1 are dice [1..6] but in calls to LuckXX() they are array indexes [0..5] */
         swap(&n0, &n1);
 
-    if (is_init_board && n0 != n1)
+    if (is_init_board && n0 != n1)      /* FIXME: this fails if we return to the inital position after a few moves */
         return LuckFirst(anBoard, n0, n1, &ci, &ecLuck);
     else
         return LuckNormal(anBoard, n0, n1, &ci, &ecLuck);
@@ -416,16 +415,16 @@ updateStatcontext(statcontext * psc, const moverecord * pmr, const matchstate *
             ApplyMove(anBoardMove, pmr->n.anMove, FALSE);
             PositionKey((ConstTanBoard) anBoardMove, &key);
             rChequerSkill = 0.0f;
+            if (pmr->ml.amMoves) {
+                for (i = 0; i < pmr->ml.cMoves; i++)
 
-            for (i = 0; i < pmr->ml.cMoves; i++)
+                    if (EqualKeys(key, pmr->ml.amMoves[i].key)) {
 
-                if (EqualKeys(key, pmr->ml.amMoves[i].key)) {
-
-                    rChequerSkill = pmr->ml.amMoves[i].rScore - pmr->ml.amMoves[0].rScore;
-
-                    break;
-                }
+                        rChequerSkill = pmr->ml.amMoves[i].rScore - pmr->ml.amMoves[0].rScore;
 
+                        break;
+                    }
+            }
             /* update statistics */
 
             rCost = pms->nMatchTo ? eq2mwc(rChequerSkill, &ci) - eq2mwc(0.0f, &ci) : pms->nCube * rChequerSkill;
@@ -672,8 +671,10 @@ AnalyzeMove(moverecord * pmr, matchstate * pms, const listOLD * plParentGame,
 
             if (cmp_evalsetup(pesChequer, &pmr->esChequer) > 0) {
 
-                if (pmr->ml.cMoves)
+                if (pmr->ml.cMoves) {
                     free(pmr->ml.amMoves);
+                    pmr->ml.amMoves = NULL;
+                }
 
                 /* find best moves */
 
@@ -944,7 +945,7 @@ AnalyzeGame(listOLD * plGame, int wait)
     g_assert(pmr->mt == MOVE_GAMEINFO);
     if (AnalyzeMove(pmr, &msAnalyse, plGame, psc,
                     &esAnalysisChequer, &esAnalysisCube, aamfAnalysis, afAnalysePlayers, NULL) < 0)
-        return -1;              /* Interupted */
+        return -1;              /* Interrupted */
 
     numMoves--;                 /* Done one - the gameinfo */
 
@@ -2216,7 +2217,7 @@ cmark_move_rollout(moverecord * pmr, gboolean destroy)
     move **ppm;
     void *p;
     GSList *list = NULL;
-    positionkey key = { {0, 0, 0, 0, 0, 0} };
+    positionkey key = { {0, 0, 0, 0, 0, 0, 0} };
 
     g_return_val_if_fail(pmr, -1);
 
@@ -2244,7 +2245,7 @@ cmark_move_rollout(moverecord * pmr, gboolean destroy)
     }
 
     RolloutProgressStart(&ci, c, NULL, &rcRollout, asz, TRUE, &p);
-    ScoreMoveRollout(ppm, (const cubeinfo **) ppci, c, RolloutProgress, p);
+    ScoreMoveRollout(ppm, ppci, c, RolloutProgress, p);
     res = RolloutProgressEnd(&p, destroy);
 
     g_free(asz);
