@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: backgammon.h,v 1.450 2014/07/29 15:08:16 plm Exp $
+ * $Id: backgammon.h,v 1.454 2015/01/25 11:27:10 plm Exp $
  */
 
 #ifndef BACKGAMMON_H
@@ -102,7 +102,6 @@ typedef enum _movetype {
 } movetype;
 
 typedef struct _movegameinfo {
-
     /* ordinal number of the game within a match */
     int i;
     /* match length */
@@ -396,7 +395,6 @@ extern unsigned int nDefaultLength;
 extern rngcontext *rngctxRollout;
 
 extern command acAnnotateMove[];
-extern command acSet[];
 extern command acSetAnalysisPlayer[];
 extern command acSetCheatPlayer[];
 extern command acSetEvalParam[];
@@ -413,8 +411,6 @@ extern command acSetRolloutLimit[];
 extern command acSetRolloutPlayer[];
 extern command acSetTruncation[];
 extern command acTop[];
-extern command cFilename;
-extern command cOnOff;
 
 extern int fInteractive;
 
@@ -463,7 +459,6 @@ extern int InternalCommandNext(int mark, int cmark, int n);
 extern int NextTurn(int fPlayNext);
 extern int ParseKeyValue(char **ppch, char *apch[2]);
 extern int ParseNumber(char **ppch);
-extern gboolean ParseULong(char **ppch, unsigned long *pretVal);
 extern int ParsePlayer(char *sz);
 extern int ParsePosition(TanBoard an, char **ppch, char *pchDesc);
 extern int SetToggle(const char *szName, int *pf, char *sz, const char *szOn, const char *szOff);
@@ -1002,9 +997,7 @@ extern int getMoveNumber(const listOLD * plGame, const void *p);
 extern int CheckGameExists(void);
 extern void pmr_cubedata_set(moverecord * pmr, evalsetup * es, float output[2][NUM_ROLLOUT_OUTPUTS],
                              float stddev[2][NUM_ROLLOUT_OUTPUTS]);
-extern void pmr_cubedata_copy(const moverecord * source, moverecord * target);
 extern void pmr_movelist_set(moverecord * pmr, evalsetup * pes, movelist * pml);
-extern void pmr_movelist_copy(const moverecord * source, moverecord * target);
 extern void current_pmr_cubedata_update(evalsetup * pes, float output[][NUM_ROLLOUT_OUTPUTS],
                                         float stddev[][NUM_ROLLOUT_OUTPUTS]);
 extern listOLD *game_add_pmr_hint(listOLD * plGame);
@@ -1028,7 +1021,6 @@ extern void SetRNG(rng * prng, rngcontext * rngctx, rng rngNew, char *szSeed);
 extern int check_resigns(cubeinfo * pci);
 extern int quick_roll(void);
 extern int board_in_list(const movelist * pml, const TanBoard old_board, const TanBoard board, int *an);
-extern unsigned int getDiceRandomDotOrg(void);
 extern int GetManualDice(unsigned int anDice[2]);
 
 #endif	/* BACKGAMMON_H */
