@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: inc3d.h,v 1.52 2013/06/16 02:16:22 mdpetch Exp $
+ * $Id: inc3d.h,v 1.55 2015/01/17 21:52:24 mdpetch Exp $
  */
 #ifndef INC3D_H
 #define INC3D_H
@@ -35,6 +35,7 @@
 
 #if defined(WIN32)
 /* MS gl.h needs windows.h to be included first */
+#include <winsock2.h>
 #include <windows.h>
 #endif
 
@@ -58,14 +59,12 @@
 #include "model.h"
 #include "drawboard.h"          /* for fClockwise decl */
 
-/* float versions (to quiet compiler warnings) */
-#define powi(arg1, arg2) (int)pow((double)(arg1), (double)(arg2))
-
 /* Clipping planes */
 #define zNear .1
 #define zFar 70.0
 
 extern int numRestrictFrames;
+extern int renderingBase;
 
 typedef enum _BoardState {
     BOARD_CLOSED, BOARD_CLOSING, BOARD_OPENING, BOARD_OPEN
