@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: misc3d.c,v 1.111 2013/06/16 02:16:22 mdpetch Exp $
+ * $Id: misc3d.c,v 1.113 2014/09/03 21:48:52 plm Exp $
  */
 
 #include "config.h"
@@ -565,7 +565,6 @@ int
 LoadTexture(Texture * texture, const char *filename)
 {
     unsigned char *bits = 0;
-    int n;
     GError *pix_error = NULL;
     GdkPixbuf *fpixbuf, *pixbuf;
 
@@ -604,8 +603,7 @@ LoadTexture(Texture * texture, const char *filename)
         return 0;               /* failed to load file */
     }
     /* Check size is a power of 2 */
-    frexp((double) texture->width, &n);
-    if (texture->width != powi(2, n - 1)) {
+    if (texture->width <= 0 || (texture->width & (texture->width -1))) {
         g_print("Failed to load texture %s, size (%d) isn't a power of 2\n", filename, texture->width);
         return 0;               /* failed to load file */
     }
@@ -687,6 +685,7 @@ GetTextures(BoardData3d * bd3d, renderdata * prd)
 void
 Set3dSettings(renderdata * prdnew, const renderdata * prd)
 {
+    unsigned int i;
     prdnew->pieceType = prd->pieceType;
     prdnew->pieceTextureType = prd->pieceTextureType;
     prdnew->fHinges3d = prd->fHinges3d;
@@ -703,6 +702,12 @@ Set3dSettings(renderdata * prdnew, const renderdata * prd)
     prdnew->diceSize = prd->diceSize;
     prdnew->planView = prd->planView;
 
+    prdnew->lightType = prd->lightType;
+    for (i = 0; i < 3; i++) {
+      prdnew->lightPos[i] = prd->lightPos[i];
+      prdnew->lightLevels[i] = prd->lightLevels[i];
+    }
+
     memcpy(prdnew->ChequerMat, prd->ChequerMat, sizeof(Material[2]));
     memcpy(&prdnew->DiceMat[0], prd->afDieColour3d[0] ? &prd->ChequerMat[0] : &prd->DiceMat[0], sizeof(Material));
     memcpy(&prdnew->DiceMat[1], prd->afDieColour3d[1] ? &prd->ChequerMat[1] : &prd->DiceMat[1], sizeof(Material));
