@@ -12,7 +12,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: common.h,v 1.30 2014/09/14 21:14:09 plm Exp $
+ * $Id: common.h,v 1.31 2015/01/17 21:52:23 mdpetch Exp $
  */
 
 /*! \file common.h
@@ -59,10 +59,18 @@ typedef void (*psighandler) (int);
 /* Do we need to use g_utf8_casefold() for utf8 anywhere? */
 #define StrCaseCmp(s1, s2) g_ascii_strcasecmp(s1, s2)
 #define StrNCaseCmp(s1, s2, n) g_ascii_strncasecmp(s1, s2, (gsize)n)
+/* if the following are defined as macros undefine them */
+#ifdef strcasecmp
+#undef strcasecmp
+#endif
+#ifdef strncasecmp
+#undef strncasecmp
+#endif
 /* Avoid new code using strcase functions */
 #define strcasecmp strcasecmp_error_use_StrCaseCmp
 #define strncasecmp strncasecmp_error_use_StrNCaseCmp
 
+
 /* Macro to mark parameters that aren't used in the function */
 #ifdef UNUSED
 #elif defined(__GNUC__)
