@@ -19,11 +19,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dbprovider.c,v 1.42 2013/07/26 21:20:46 plm Exp $
+ * $Id: dbprovider.c,v 1.49 2015/04/14 22:17:15 plm Exp $
  */
 
 #include "config.h"
 #include "gnubgmodule.h"
+#include "stdlib.h"
 
 #include "backgammon.h"
 #include <glib/gstdio.h>
@@ -34,7 +35,9 @@ DBProviderType dbProviderType = (DBProviderType) 0;
 int storeGameStats = TRUE;
 
 #if USE_PYTHON
-PyObject *pdict;
+#include "pylocdefs.h"
+
+static PyObject *pdict;
 RowSet *ConvertPythonToRowset(PyObject * v);
 
 #if !USE_SQLITE
@@ -65,7 +68,7 @@ static void SQLiteCommit(void);
 #if NUM_PROVIDERS
 static int SQLiteDeleteDatabase(const char *dbfilename, const char *user, const char *password, const char *hostname);
 static GList *SQLiteGetDatabaseList(const char *user, const char *password, const char *hostname);
-DBProvider providers[NUM_PROVIDERS] = {
+static DBProvider providers[NUM_PROVIDERS] = {
 #if USE_SQLITE
     {SQLiteConnect, SQLiteDisconnect, SQLiteSelect, SQLiteUpdateCommand, SQLiteCommit, SQLiteGetDatabaseList,
      SQLiteDeleteDatabase,
@@ -281,7 +284,7 @@ GetDBProvider(DBProviderType dbType)
 int
 PyMySQLConnect(const char *dbfilename, const char *user, const char *password, const char *hostname)
 {
-    int iret;
+    long iret;
     PyObject *ret;
 
     const char *host = hostname ? hostname : "";
@@ -293,7 +296,7 @@ PyMySQLConnect(const char *dbfilename, const char *user, const char *password, c
     if (ret == NULL || !PyInt_Check(ret) || (iret = PyInt_AsLong(ret)) < 0) {
         PyErr_Print();
         return -1;
-    } else if (iret == 0) {     /* New database - populate */
+    } else if (iret == 0L) {     /* New database - populate */
         return 0;
     }
     return 1;
@@ -303,7 +306,7 @@ PyMySQLConnect(const char *dbfilename, const char *user, const char *password, c
 int
 PyPostgreConnect(const char *dbfilename, const char *user, const char *password, const char *hostname)
 {
-    int iret;
+    long iret;
     PyObject *ret;
     const char *host = hostname ? hostname : "";
 
@@ -314,7 +317,7 @@ PyPostgreConnect(const char *dbfilename, const char *user, const char *password,
     if (ret == NULL || !PyInt_Check(ret) || (iret = PyInt_AsLong(ret)) < 0) {
         PyErr_Print();
         return -1;
-    } else if (iret == 0) {     /* New database - populate */
+    } else if (iret == 0L) {     /* New database - populate */
         return 0;
     }
     return 1;
@@ -454,12 +457,12 @@ ConvertPythonToRowset(PyObject * v)
                     continue;
                 }
                 if (PyUnicode_Check(e2))
-                    strcpy(buf, PyString_AsString(PyUnicode_AsUTF8String(e2)));
-                else if (PyString_Check(e2))
-                    strcpy(buf, PyString_AsString(e2));
+                    strcpy(buf, PyBytes_AsString(PyUnicode_AsUTF8String(e2)));
+                else if (PyBytes_Check(e2))
+                    strcpy(buf, PyBytes_AsString(e2));
                 else if (PyInt_Check(e2) || PyLong_Check(e2)
                          || !StrCaseCmp(e2->ob_type->tp_name, "Decimal"))       /* Not sure how to check for decimal type directly */
-                    sprintf(buf, "%d", (int) PyInt_AsLong(e2));
+                    sprintf(buf, "%ld", PyInt_AsLong(e2));
                 else if (PyFloat_Check(e2))
                     sprintf(buf, "%.4f", PyFloat_AsDouble(e2));
                 else if (e2 == Py_None)
@@ -566,7 +569,7 @@ PyPostgreDeleteDatabase(const char *dbfilename, const char *user, const char *pa
 
 #include <sqlite3.h>
 
-sqlite3 *connection;
+static sqlite3 *connection;
 
 int
 SQLiteConnect(const char *dbfilename, const char *UNUSED(user), const char *UNUSED(password),
