@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: export.c,v 1.78 2013/07/26 21:21:34 plm Exp $
+ * $Id: export.c,v 1.82 2015/04/12 22:00:25 plm Exp $
  */
 
 #include "config.h"
@@ -163,8 +163,7 @@ draw_simple_board_on_cairo(matchstate * sb_pms,
 
     simple_board_draw(board);
     g_free(board);
-    if (header)
-        g_string_free(header, TRUE);
+    g_string_free(header, TRUE);
     if (annotation)
         g_string_free(annotation, TRUE);
     return 1;
@@ -607,7 +606,7 @@ GenerateImage(renderimages * pri, renderdata * prd,
     color = fMove;
 
     CalculateArea(prd, puch, BOARD_WIDTH * nSize * 3, pri, anBoardTemp, NULL,
-                  (int *) anDice, anDicePosition,
+                  anDice, anDicePosition,
                   color, anCubePosition,
                   LogCube(nCube) + (doubled != 0),
                   nOrient,
@@ -1051,7 +1050,7 @@ ExportGameJF(FILE * pf, listOLD * plGame, int iGame, int withScore, int fSst)
             break;
         case MOVE_NORMAL:
             diceRolled = 0;
-            sprintf(sz, "%d%d: ", pmr->anDice[0], pmr->anDice[1]);
+            sprintf(sz, "%u%u: ", pmr->anDice[0], pmr->anDice[1]);
             if (fSst) {         /* Snowie standard text */
                 moverecord *pnextmr;
                 if (pl->plNext && pl->plNext->p) {
@@ -1096,7 +1095,7 @@ ExportGameJF(FILE * pf, listOLD * plGame, int iGame, int withScore, int fSst)
             break;
         case MOVE_SETDICE:
             /* Could be rolled dice just before resign or an illegal move */
-            sprintf(sz, "%d%d: ", pmr->anDice[0], pmr->anDice[1]);
+            sprintf(sz, "%u%u: ", pmr->anDice[0], pmr->anDice[1]);
             diceRolled = 1;
             break;
         case MOVE_SETBOARD:
@@ -1168,7 +1167,7 @@ ExportGameJF(FILE * pf, listOLD * plGame, int iGame, int withScore, int fSst)
 
         if ((n = GameStatus((ConstTanBoard) anBoard, ms.bgv))) {
             fprintf(pf, "%sWins %d point%s%s\n\n",
-                    i & 1 ? "                                  " : "\n      ",
+                    (i & 1) ? "                                  " : "\n      ",
                     n * nFileCube, n * nFileCube > 1 ? "s" : "", "" /* FIXME " and the match" if appropriate */ );
         }
         i++;
@@ -1263,8 +1262,20 @@ ExportMatchMat(char *sz, int fSst)
             fprintf(pf, "; [Round \"%s\"]\n", mi.pchRound);
         if (mi.nYear > 1900)
             fprintf(pf, "; [EventDate \"%4u.%02u.%02u\"]\n", mi.nYear, mi.nMonth, mi.nDay);
-        if (ms.bgv == VARIATION_NACKGAMMON)
+        switch (ms.bgv) {
+        case VARIATION_NACKGAMMON:
             fprintf(pf, "; [Variation \"NackGammon\"]\n");
+            break;
+        case VARIATION_HYPERGAMMON_1:
+            fprintf(pf, "; [Variation \"HyperGammon (1)\"]\n");
+            break;
+        case VARIATION_HYPERGAMMON_2:
+            fprintf(pf, "; [Variation \"HyperGammon (2)\"]\n");
+            break;
+        case VARIATION_HYPERGAMMON_3:
+            fprintf(pf, "; [Variation \"HyperGammon (3)\"]\n");
+            break;
+        }
         if (mi.pchAnnotator)
             fprintf(pf, "; [Transcriber \"%s\"]\n", mi.pchAnnotator);
         if (mi.pchComment) {
