@@ -16,16 +16,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: external.c,v 1.74 2013/06/16 02:16:11 mdpetch Exp $
+ * $Id: external.c,v 1.94 2015/02/08 15:19:07 plm Exp $
  */
 
 #include "config.h"
 
 #if HAVE_SOCKETS
 
+#define DEBUG_PREFIX "DBG: "
+
+#include <stdlib.h>
 #include <signal.h>
 #include <glib.h>
 #include <glib/gstdio.h>
+#include "glib-ext.h"
 
 #if HAVE_UNISTD_H
 #include <unistd.h>
@@ -33,8 +37,8 @@
 
 #ifndef WIN32
 
+#include <stdio.h>
 #include <errno.h>
-#include <stdlib.h>
 #include <string.h>
 
 #if HAVE_SYS_SOCKET_H
@@ -46,10 +50,8 @@
 #include <sys/un.h>
 #endif                          /* #if HAVE_SYS_SOCKET_H */
 
-#include <stdio.h>
-
 #else                           /* #ifndef WIN32 */
-#include <stdlib.h>
+
 #include <winsock2.h>
 #include <ws2tcpip.h>
 
@@ -104,15 +106,11 @@
 #include "drawboard.h"
 #include "external.h"
 #include "rollout.h"
+#include "eval.h"
+#include "matchid.h"
+#include "lib/gnubg-types.h"
 
 #if HAVE_SOCKETS
-/* Stuff for the yacc/lex parser */
-
-extern extcmd ec;
-static int fError = FALSE;
-static char *szError = NULL;
-extern void ExtStartParse(const char *s);
-
 
 #if defined(AF_UNIX) && !defined(AF_LOCAL)
 #define AF_LOCAL AF_UNIX
@@ -183,12 +181,7 @@ ExternalSocket(struct sockaddr **ppsa, int *pcb, char *sz)
                 free(psin);
                 return -1;
             }
-#ifdef WIN32
-            memcpy(&(psin->sin_addr), (struct in_addr *) (phe->h_addr), phe->h_length);
-#else
-            psin->sin_addr = *(struct in_addr *) phe->h_addr;
-#endif                          /* WIN32 */
-
+			memcpy(&(psin->sin_addr), phe->h_addr, phe->h_length); 
         }
 
         *pch++ = ':';
@@ -204,7 +197,7 @@ ExternalSocket(struct sockaddr **ppsa, int *pcb, char *sz)
 
         /* yuck... there's no portable way to obtain the necessary
          * sockaddr_un size, but this is a conservative estimate */
-        psun = malloc(*pcb = 16 + strlen(sz));
+        psun = malloc(*pcb = 16 + (int) strlen(sz));
 
         psun->sun_family = AF_LOCAL;
         strcpy(psun->sun_path, sz);
@@ -238,16 +231,18 @@ ExternalRead(int h, char *pch, size_t cch)
 {
 
     char *p = pch, *pEnd;
-    int n;
 #ifndef WIN32
+    ssize_t n;
     psighandler sh;
+#else
+    int n;
 #endif
 
     while (cch) {
         ProcessEvents();
 
         if (fInterrupt)
-            return -1;
+            return -2;
 
 #ifndef WIN32
         PortableSignal(SIGPIPE, SIG_IGN, &sh, FALSE);
@@ -297,9 +292,11 @@ ExternalWrite(int h, char *pch, size_t cch)
 {
 
     char *p = pch;
-    int n;
 #ifndef WIN32
+    ssize_t n;
     psighandler sh;
+#else
+    int n;
 #endif
 
     while (cch) {
@@ -345,60 +342,74 @@ ExternalWrite(int h, char *pch, size_t cch)
 
 #if HAVE_SOCKETS
 static void
-ErrorHandler(const char *szMessage, const char *szNear, const int UNUSED(fParseError))
+unset_scan_context(scancontext * pScanCtx, int bFreeScanner)
 {
+    if (pScanCtx->bi.gsName)
+        g_string_free(pScanCtx->bi.gsName, TRUE);
+    if (pScanCtx->bi.gsOpp)
+        g_string_free(pScanCtx->bi.gsOpp, TRUE);
+    if (pScanCtx->szError)
+        g_free(pScanCtx->szError);
 
-    fError = TRUE;
-
-    g_free(szError);
-    szError = g_strdup_printf("Error (%s) near '%s'\n", szMessage, szNear);
+    pScanCtx->bi.gsName = NULL;
+    pScanCtx->bi.gsOpp = NULL;
+    pScanCtx->szError = NULL;
+    pScanCtx->fError = 0;
 
+    if (bFreeScanner) {
+        ExtDestroyParse(pScanCtx->scanner);
+        pScanCtx->scanner = NULL;
+    }
 }
 
-static extcmd *
-ExtParse(const char *szCommand)
+static void
+ErrorHandler(scancontext * pScanCtx, const char *szMessage)
 {
+    pScanCtx->fError = TRUE;
+    if (pScanCtx->szError)
+        g_free(pScanCtx->szError);
 
-    ExtErrorHandler = ErrorHandler;
-    fError = FALSE;
-    szError = NULL;
-    ExtStartParse(szCommand);
+    pScanCtx->szError = g_strdup_printf("Error: %s\n", szMessage);
+}
 
-    return fError ? NULL : &ec;
+static scancontext *
+ExtParse(scancontext * scanctx, const char *szCommand)
+{
+    scanctx->ExtErrorHandler = ErrorHandler;
+    scanctx->fError = FALSE;
+    scanctx->szError = NULL;
 
+    ExtStartParse(scanctx->scanner, szCommand);
+    return scanctx->fError ? NULL : scanctx;
 }
 
 static char *
-ExtEvaluation(extcmd * pec)
+ExtEvaluation(scancontext * pec)
 {
-
-    char szName[MAX_NAME_LEN], szOpp[MAX_NAME_LEN];
-    int nMatchTo, anScore[2], anDice[2], nCube, fCubeOwner, fDoubled, fCrawford, fJacoby;
-    TanBoard anBoard;
+    ProcessedFIBSBoard processedBoard;
     float arOutput[NUM_ROLLOUT_OUTPUTS];
     cubeinfo ci;
-    int nScore, nScoreOpponent;
+    int anScore[2];
     char *szResponse;
     float r;
     evalcontext ec;
 
-    if (ParseFIBSBoard(pec->szFIBSBoard, anBoard, szName, szOpp, &nMatchTo,
-                       &nScore, &nScoreOpponent, anDice, &nCube, &fCubeOwner, &fDoubled, &fCrawford)) {
-        outputl(_("Warning: badly formed board from external controller."));
-        szResponse = g_strdup_printf("Error: badly formed board ('%s')\n", pec->szFIBSBoard);
+    if (ProcessFIBSBoardInfo(&pec->bi, &processedBoard)) {
+        szResponse = g_strdup_printf("Error: badly formed board\n");
     } else {
 
-        anScore[0] = nScoreOpponent;
-        anScore[1] = nScore;
+        anScore[0] = processedBoard.nScoreOpp;
+        anScore[1] = processedBoard.nScore;
         /* If the session isn't using Crawford rule, set crawford flag to false */
-        fCrawford = pec->fCrawfordRule ? fCrawford : FALSE;
+        processedBoard.fCrawford = pec->fCrawfordRule ? processedBoard.fCrawford : FALSE;
         /* Set the Jacoby flag appropriately from the external interface settings */
-        fJacoby = pec->fJacobyRule;
+        processedBoard.fJacoby = pec->fJacobyRule;
 
         /* printf ("Jacoby Setting: %d\n", fJacoby); */
         /* printf ("Crawford Setting: %d\n", fCrawford); */
 
-        SetCubeInfo(&ci, nCube, fCubeOwner, 1, nMatchTo, anScore, fCrawford, fJacoby, nBeavers, bgvDefault);
+        SetCubeInfo(&ci, processedBoard.nCube, processedBoard.fCubeOwner, 1, processedBoard.nMatchTo,
+                    anScore, processedBoard.fCrawford, processedBoard.fJacoby, nBeavers, bgvDefault);
 
         ec.fCubeful = pec->fCubeful;
         ec.nPlies = pec->nPlies;
@@ -406,10 +417,10 @@ ExtEvaluation(extcmd * pec)
         ec.fDeterministic = pec->fDeterministic;
         ec.rNoise = pec->rNoise;
 
-        if (GeneralEvaluationE(arOutput, (ConstTanBoard) anBoard, &ci, &ec))
+        if (GeneralEvaluationE(arOutput, (ConstTanBoard) processedBoard.anBoard, &ci, &ec))
             return NULL;
 
-        if (nMatchTo) {
+        if (processedBoard.nMatchTo) {
             if (ec.fCubeful)
                 r = arOutput[OUTPUT_CUBEFUL_EQUITY];
             else
@@ -426,58 +437,43 @@ ExtEvaluation(extcmd * pec)
 }
 
 static char *
-ExtFIBSBoard(extcmd * pec)
+ExtFIBSBoard(scancontext * pec)
 {
-
-    char szName[MAX_NAME_LEN], szOpp[MAX_NAME_LEN];
-    int nMatchTo, anScore[2], anDice[2], nCube, fCubeOwner, fDoubled, fCrawford, fJacoby, anMove[8], fTurn;
-    TanBoard anBoard, anBoardOrig;
+    ProcessedFIBSBoard processedBoard;
+    TanBoard anBoardOrig;
+    int anScore[2], anMove[8], fTurn;
     float arDouble[NUM_CUBEFUL_OUTPUTS], aarOutput[2][NUM_ROLLOUT_OUTPUTS], aarStdDev[2][NUM_ROLLOUT_OUTPUTS];
     rolloutstat aarsStatistics[2][2];
     cubeinfo ci;
-    int nScore, nScoreOpponent;
     char *szResponse;
 
-    if (ParseFIBSBoard(pec->szFIBSBoard, anBoard, szName, szOpp, &nMatchTo,
-                       &nScore, &nScoreOpponent, anDice, &nCube, &fCubeOwner, &fDoubled, &fCrawford)) {
-        outputl(_("Warning: badly formed board from external controller."));
-        szResponse = g_strdup_printf("Error: badly formed board ('%s')\n", pec->szFIBSBoard);
+    if (ProcessFIBSBoardInfo(&pec->bi, &processedBoard)) {
+        szResponse = g_strdup_printf("Error: badly formed board\n");
     } else {
 
-        anScore[0] = nScoreOpponent;
-        anScore[1] = nScore;
+        anScore[0] = processedBoard.nScoreOpp;
+        anScore[1] = processedBoard.nScore;
 
         /* If the session isn't using Crawford rule, set crawford flag to false */
-        fCrawford = pec->fCrawfordRule ? fCrawford : FALSE;
+        processedBoard.fCrawford = pec->fCrawfordRule ? processedBoard.fCrawford : FALSE;
         /* Set the Jacoby flag appropriately from the external interface settings */
-        fJacoby = pec->fJacobyRule;
+        processedBoard.fJacoby = pec->fJacobyRule;
 
         /* printf ("Crawford Setting: %d\n", fCrawford); */
         /* printf ("Jacoby Setting: %d\n", fJacoby); */
 
         fTurn = 1;
-        SetCubeInfo(&ci, nCube, fCubeOwner, fTurn, nMatchTo, anScore, fCrawford, fJacoby, nBeavers, bgvDefault);
+        SetCubeInfo(&ci, processedBoard.nCube, processedBoard.fCubeOwner, fTurn, processedBoard.nMatchTo,
+                    anScore, processedBoard.fCrawford, processedBoard.fJacoby, nBeavers, bgvDefault);
 
-#if 0
-        {
-            char *asz[7] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL };
-            char szBoard[10000];
-            outputl(DrawBoard(szBoard, anBoard, 1, asz, "no matchid", 15));
+        memcpy(anBoardOrig, processedBoard.anBoard, sizeof(processedBoard.anBoard));
 
-            printf("score %d-%d to %d ", anScore[0], anScore[1], nMatchTo);
-            printf("dice %d %d ", anDice[0], anDice[1]);
-            printf("cubeowner %d cube %d turn %d crawford %d doubled %d\n",
-                   fCubeOwner, nCube, fTurn, fCrawford, fDoubled);
-        }
-#endif
-
-        memcpy(anBoardOrig, anBoard, sizeof(anBoard));
-
-        if (fDoubled) {
+        if (processedBoard.fDoubled) {
 
             /* take decision */
             if (GeneralCubeDecision(aarOutput, aarStdDev,
-                                    aarsStatistics, (ConstTanBoard) anBoard, &ci, GetEvalCube(), NULL, NULL) < 0)
+                                    aarsStatistics, (ConstTanBoard) processedBoard.anBoard, &ci, GetEvalCube(), NULL,
+                                    NULL) < 0)
                 return NULL;
 
             switch (FindCubeDecision(arDouble, aarOutput, &ci)) {
@@ -498,20 +494,17 @@ ExtFIBSBoard(extcmd * pec)
                 szResponse = g_strdup("take\n");
             }
 
-#if 0
-            /* this code is broken as the sign of fDoubled 
-             * indicates who doubled */
-        } else if (fDoubled < 0) {
+        } else if (pec->nResignation) {
 
             /* if opp wants to resign (extension to FIBS board) */
 
             float arOutput[NUM_ROLLOUT_OUTPUTS];
             float rEqBefore, rEqAfter;
-            const float epsilon = 1.0e-6;
+            const float epsilon = 1.0e-6f;
 
-            getResignation(arOutput, anBoard, &ci, &esEvalCube);
+            getResignation(arOutput, processedBoard.anBoard, &ci, &esEvalCube);
 
-            getResignEquities(arOutput, &ci, -fDoubled, &rEqBefore, &rEqAfter);
+            getResignEquities(arOutput, &ci, pec->nResignation, &rEqBefore, &rEqAfter);
 
             /* if opponent gives up equity by resigning */
             if ((rEqAfter - epsilon) < rEqBefore)
@@ -519,12 +512,11 @@ ExtFIBSBoard(extcmd * pec)
             else
                 szResponse = g_strdup("reject\n");
 
-#endif                          /* broken */
-        } else if (anDice[0]) {
+        } else if (processedBoard.anDice[0]) {
             /* move */
             char szMove[64];
-            if (FindBestMove(anMove, anDice[0], anDice[1],
-                             anBoard, &ci, &GetEvalChequer()->ec, *GetEvalMoveFilter()) < 0)
+            if (FindBestMove(anMove, processedBoard.anDice[0], processedBoard.anDice[1],
+                             processedBoard.anBoard, &ci, &GetEvalChequer()->ec, *GetEvalMoveFilter()) < 0)
                 return NULL;
 
             FormatMovePlain(szMove, anBoardOrig, anMove);
@@ -532,7 +524,8 @@ ExtFIBSBoard(extcmd * pec)
         } else {
             /* double decision */
             if (GeneralCubeDecision(aarOutput, aarStdDev,
-                                    aarsStatistics, (ConstTanBoard) anBoard, &ci, GetEvalCube(), NULL, NULL) < 0)
+                                    aarsStatistics, (ConstTanBoard) processedBoard.anBoard, &ci, GetEvalCube(),
+                                    NULL, NULL) < 0)
                 return NULL;
 
             switch (FindCubeDecision(arDouble, aarOutput, &ci)) {
@@ -570,7 +563,10 @@ CommandExternal(char *sz)
     char *szResponse = NULL;
     struct sockaddr_in saRemote;
     socklen_t saLen;
-    extcmd *pec;
+    scancontext scanctx;
+    int fExit;
+    int fRestart = TRUE;
+    int retval;
 
     sz = NextToken(&sz);
 
@@ -579,11 +575,18 @@ CommandExternal(char *sz)
         return;
     }
 
+    memset(&scanctx, 0, sizeof(scanctx));
+    ExtInitParse(&scanctx.scanner);
+
   listenloop:
     {
+        fExit = FALSE;
+        scanctx.fDebug = FALSE;
+        scanctx.fNewInterface = FALSE;
 
         if ((h = ExternalSocket(&psa, &cb, sz)) < 0) {
             SockErr(sz);
+            ExtDestroyParse(scanctx.scanner);
             return;
         }
 
@@ -591,6 +594,7 @@ CommandExternal(char *sz)
             SockErr(sz);
             closesocket(h);
             free(psa);
+            ExtDestroyParse(scanctx.scanner);
             return;
         }
 
@@ -600,6 +604,7 @@ CommandExternal(char *sz)
             SockErr("listen");
             closesocket(h);
             ExternalUnbind(sz);
+            ExtDestroyParse(scanctx.scanner);
             return;
         }
         outputf(_("Waiting for a connection from %s...\n"), sz);
@@ -615,6 +620,7 @@ CommandExternal(char *sz)
                 if (fInterrupt) {
                     closesocket(h);
                     ExternalUnbind(sz);
+                    ExtDestroyParse(scanctx.scanner);
                     return;
                 }
 
@@ -624,6 +630,7 @@ CommandExternal(char *sz)
             SockErr("accept");
             closesocket(h);
             ExternalUnbind(sz);
+            ExtDestroyParse(scanctx.scanner);
             return;
         }
 
@@ -636,30 +643,142 @@ CommandExternal(char *sz)
         outputx();
         ProcessEvents();
 
-        while (!ExternalRead(hPeer, szCommand, sizeof(szCommand))) {
+        while (!fExit && !(retval = ExternalRead(hPeer, szCommand, sizeof(szCommand)))) {
+            /* To keep lexer happy terminate each line with \n */
+            if (szCommand[strlen(szCommand)-1] != '\n')
+                strcat(szCommand, "\n");
 
-            if ((pec = ExtParse(szCommand)) == 0) {
+            if ((ExtParse(&scanctx, szCommand)) == 0) {
                 /* parse error */
-                szResponse = szError;
+                szResponse = scanctx.szError;
             } else {
+                ProcessedFIBSBoard processedBoard;
+                GValue *optionsmapgv;
+                GValue *boarddatagv;
+                GString *dbgStr;
+                int anScore[2];
+                int fCrawford, fJacoby;
+                char *asz[7] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL };
+                char szBoard[10000];
+                char **aszLines;
+                char **aszLinesOrig;
+                char *szMatchID;
+                gchar *szOptStr;
+
+                switch (scanctx.ct) {
+                case COMMAND_HELP:
+                    szResponse = g_strdup("\tNo help information available\n");
+                    break;
+
+                case COMMAND_SET:
+                    szOptStr = g_value_get_gstring_gchar(g_list_nth_data(scanctx.pCmdData, 0));
+                    if (g_ascii_strcasecmp(szOptStr, KEY_STR_DEBUG) == 0) {
+                        scanctx.fDebug = g_value_get_int(g_list_nth_data(scanctx.pCmdData, 1));
+                        szResponse = g_strdup_printf("Debug output %s\n", scanctx.fDebug ? "ON" : "OFF");
+                    } else if (g_ascii_strcasecmp(szOptStr, KEY_STR_NEWINTERFACE) == 0) {
+                        scanctx.fNewInterface = g_value_get_int(g_list_nth_data(scanctx.pCmdData, 1));
+                        szResponse = g_strdup_printf("New interface %s\n", scanctx.fNewInterface ? "ON" : "OFF");
+                    } else {
+                        szResponse = g_strdup_printf("Error: set option '%s' not supported\n", szOptStr);
+                    }
+                    g_list_gv_boxed_free(scanctx.pCmdData);
+
+                    break;
+
+                case COMMAND_VERSION:
+                    szResponse = g_strdup("Interface: " EXTERNAL_INTERFACE_VERSION "\n"
+                                          "RFBF: " RFBF_VERSION_SUPPORTED "\n"
+                                          "Engine: " WEIGHTS_VERSION "\n" "Software: " VERSION "\n");
+
+                    break;
 
-                switch (pec->ct) {
                 case COMMAND_NONE:
                     szResponse = g_strdup("Error: no command given\n");
                     break;
 
                 case COMMAND_FIBSBOARD:
-
-                    szResponse = ExtFIBSBoard(pec);
-                    break;
-
                 case COMMAND_EVALUATION:
+                    if (scanctx.fDebug) {
+                        optionsmapgv = (GValue *) g_list_nth_data(g_value_get_boxed(scanctx.pCmdData), 1);
+                        boarddatagv = (GValue *) g_list_nth_data(g_value_get_boxed(scanctx.pCmdData), 0);
+                        dbgStr = g_string_new(DEBUG_PREFIX);
+                        g_value_tostring(dbgStr, optionsmapgv, 0);
+                        g_string_append(dbgStr, "\n" DEBUG_PREFIX);
+                        g_value_tostring(dbgStr, boarddatagv, 0);
+                        g_string_append(dbgStr, "\n" DEBUG_PREFIX "\n");
+                        ExternalWrite(hPeer, dbgStr->str, strlen(dbgStr->str));
+                        ProcessFIBSBoardInfo(&scanctx.bi, &processedBoard);
+
+                        anScore[0] = processedBoard.nScoreOpp;
+                        anScore[1] = processedBoard.nScore;
+                        /* If the session isn't using Crawford rule, set crawford flag to false */
+                        fCrawford = scanctx.fCrawfordRule ? processedBoard.fCrawford : FALSE;
+                        /* Set the Jacoby flag appropriately from the external interface settings */
+                        fJacoby = scanctx.fJacobyRule;
+
+                        szMatchID = MatchID((unsigned int *) processedBoard.anDice, 1, processedBoard.nResignation,
+                                            processedBoard.fDoubled, 1, processedBoard.fCubeOwner, fCrawford,
+                                            processedBoard.nMatchTo, anScore, processedBoard.nCube, fJacoby,
+                                            GAME_PLAYING);
+
+                        DrawBoard(szBoard, (ConstTanBoard) & processedBoard.anBoard, 1, asz, szMatchID, 15);
+
+                        aszLines = g_strsplit(&szBoard[0], "\n", 32);
+                        aszLinesOrig = aszLines;
+                        while (*aszLines) {
+                            ExternalWrite(hPeer, DEBUG_PREFIX, strlen(DEBUG_PREFIX));
+                            ExternalWrite(hPeer, *aszLines, strlen(*aszLines));
+                            ExternalWrite(hPeer, "\n", 1);
+                            aszLines++;
+                        }
+
+                        dbgStr = g_string_assign(dbgStr, "");
+                        g_string_append_printf(dbgStr, DEBUG_PREFIX "X is %s, O is %s\n", processedBoard.szPlayer,
+                                               processedBoard.szOpp);
+                        if (processedBoard.nMatchTo) {
+                            g_string_append_printf(dbgStr, DEBUG_PREFIX "Match Play %s Crawford Rule\n",
+                                                   scanctx.fCrawfordRule ? "with" : "without");
+                            g_string_append_printf(dbgStr, DEBUG_PREFIX "Score: %d-%d/%d%s, ", processedBoard.nScore,
+                                                   processedBoard.nScoreOpp, processedBoard.nMatchTo,
+                                                   fCrawford ? "*" : "");
+                        } else {
+                            g_string_append_printf(dbgStr, DEBUG_PREFIX "Money Session %s Jacoby Rule, %s Beavers\n",
+                                                   scanctx.fJacobyRule ? "with" : "without",
+                                                   scanctx.fBeavers ? "with" : "without");
+                            g_string_append_printf(dbgStr, DEBUG_PREFIX "Score: %d-%d, ", processedBoard.nScore,
+                                                   processedBoard.nScoreOpp);
+                        }
+                        g_string_append_printf(dbgStr, "Roll: %d%d\n",
+                                               processedBoard.anDice[0], processedBoard.anDice[1]);
+                        g_string_append_printf(dbgStr,
+                                               DEBUG_PREFIX
+                                               "CubeOwner: %d, Cube: %d, Turn: %c, Doubled: %d, Resignation: %d\n",
+                                               processedBoard.fCubeOwner, processedBoard.nCube, 'X',
+                                               processedBoard.fDoubled, processedBoard.nResignation);
+                        g_string_append(dbgStr, DEBUG_PREFIX "\n");
+                        ExternalWrite(hPeer, dbgStr->str, strlen(dbgStr->str));
+
+                        g_string_free(dbgStr, TRUE);
+                        g_strfreev(aszLinesOrig);
+                    }
+                    g_value_unsetfree(scanctx.pCmdData);
+
+                    if (scanctx.ct == COMMAND_EVALUATION)
+                        szResponse = ExtEvaluation(&scanctx);
+                    else
+                        szResponse = ExtFIBSBoard(&scanctx);
 
-                    szResponse = ExtEvaluation(pec);
                     break;
 
-                }
+                case COMMAND_EXIT:
+                    closesocket(hPeer);
+                    fExit = TRUE;
+                    break;
 
+                default:
+                    szResponse = g_strdup("Unsupported Command\n");
+                }
+                unset_scan_context(&scanctx, FALSE);
             }
 
             if (szResponse) {
@@ -667,11 +786,26 @@ CommandExternal(char *sz)
                     break;
 
                 g_free(szResponse);
+                szResponse = NULL;
             }
 
         }
+        /* Interrupted : get out of listen loop */
+        if (retval == -2) {
+            ProcessEvents();
+            fRestart = FALSE;
+        }
+
         closesocket(hPeer);
+        if (szResponse)
+            g_free(szResponse);
+
+        szResponse = NULL;
+        scanctx.szError = NULL;
     }
-    goto listenloop;
+    if (fRestart)
+        goto listenloop;
+
+    unset_scan_context(&scanctx, TRUE);
 #endif
 }
