@@ -37,39 +37,71 @@
    /* Put the tokens into the symbol table, so that GDB and other debuggers
       know about them.  */
    enum yytokentype {
-     STRING = 258,
-     NUMBER = 259,
-     EVALUATION = 260,
-     PLIES = 261,
-     CUBE = 262,
-     CUBEFUL = 263,
-     CUBELESS = 264,
-     NOISE = 265,
-     PRUNE = 266,
-     CRAWFORDRULE = 267,
-     JACOBYRULE = 268,
-     FIBSBOARD = 269,
-     AFIBSBOARD = 270,
-     ON = 271,
-     OFF = 272
+     EOL = 258,
+     EXIT = 259,
+     DISABLED = 260,
+     INTERFACEVERSION = 261,
+     DEBUG = 262,
+     SET = 263,
+     NEW = 264,
+     OLD = 265,
+     OUTPUT = 266,
+     E_INTERFACE = 267,
+     HELP = 268,
+     PROMPT = 269,
+     E_STRING = 270,
+     E_CHARACTER = 271,
+     E_INTEGER = 272,
+     E_FLOAT = 273,
+     E_BOOLEAN = 274,
+     FIBSBOARD = 275,
+     FIBSBOARDEND = 276,
+     EVALUATION = 277,
+     CRAWFORDRULE = 278,
+     JACOBYRULE = 279,
+     RESIGNATION = 280,
+     BEAVERS = 281,
+     CUBE = 282,
+     CUBEFUL = 283,
+     CUBELESS = 284,
+     DETERMINISTIC = 285,
+     NOISE = 286,
+     PLIES = 287,
+     PRUNE = 288
    };
 #endif
 /* Tokens.  */
-#define STRING 258
-#define NUMBER 259
-#define EVALUATION 260
-#define PLIES 261
-#define CUBE 262
-#define CUBEFUL 263
-#define CUBELESS 264
-#define NOISE 265
-#define PRUNE 266
-#define CRAWFORDRULE 267
-#define JACOBYRULE 268
-#define FIBSBOARD 269
-#define AFIBSBOARD 270
-#define ON 271
-#define OFF 272
+#define EOL 258
+#define EXIT 259
+#define DISABLED 260
+#define INTERFACEVERSION 261
+#define DEBUG 262
+#define SET 263
+#define NEW 264
+#define OLD 265
+#define OUTPUT 266
+#define E_INTERFACE 267
+#define HELP 268
+#define PROMPT 269
+#define E_STRING 270
+#define E_CHARACTER 271
+#define E_INTEGER 272
+#define E_FLOAT 273
+#define E_BOOLEAN 274
+#define FIBSBOARD 275
+#define FIBSBOARDEND 276
+#define EVALUATION 277
+#define CRAWFORDRULE 278
+#define JACOBYRULE 279
+#define RESIGNATION 280
+#define BEAVERS 281
+#define CUBE 282
+#define CUBEFUL 283
+#define CUBELESS 284
+#define DETERMINISTIC 285
+#define NOISE 286
+#define PLIES 287
+#define PRUNE 288
 
 
 
@@ -79,21 +111,27 @@ typedef union YYSTYPE
 {
 
 /* Line 2068 of yacc.c  */
-#line 49 "external_y.y"
+#line 116 "external_y.y"
 
-  int number;
-  char *sval;
+    gboolean bool;
+    gchar character;
+    gfloat floatnum;
+    gint intnum;
+    GString *str;
+    GValue *gv;
+    GList *list;
+    commandinfo *cmd;
 
 
 
 /* Line 2068 of yacc.c  */
-#line 91 "external_y.h"
+#line 129 "external_y.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
-extern YYSTYPE extlval;
+
 
 
