@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkchequer.c,v 1.117 2013/06/16 02:16:13 mdpetch Exp $
+ * $Id: gtkchequer.c,v 1.119 2015/03/01 13:14:20 plm Exp $
  */
 
 #include "config.h"
@@ -81,7 +81,7 @@ MoveListRolloutClicked(GtkWidget * pw, hintdata * phd)
         GTKSetCurrentParent(pw);
         RolloutProgressStart(&ci, c, NULL, &rcRollout, asz, FALSE, &p);
 
-        res = ScoreMoveRollout(ppm, (const cubeinfo **) ppci, c, RolloutProgress, p);
+        res = ScoreMoveRollout(ppm, ppci, c, RolloutProgress, p);
 
         RolloutProgressEnd(&p, FALSE);
 
@@ -168,7 +168,7 @@ MoveListTempMapClicked(GtkWidget * pw, hintdata * phd)
     c = g_list_length(plSelList);
 
     ams = (matchstate *) g_malloc(c * sizeof(matchstate));
-    asz = (char **) g_malloc(c * sizeof(char *));
+    asz = (gchar **) g_malloc(c * sizeof(gchar *));
 
     for (i = 0, pl = plSelList; pl; pl = pl->next, ++i) {
 
@@ -195,7 +195,7 @@ MoveListTempMapClicked(GtkWidget * pw, hintdata * phd)
     MoveListFreeSelectionList(plSelList);
 
     GTKSetCurrentParent(pw);
-    GTKShowTempMap(ams, c, (const gchar **) asz, TRUE);
+    GTKShowTempMap(ams, c, asz, TRUE);
 
     g_free(ams);
     for (i = 0; i < c; ++i)
