@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkmovelistctrl.c,v 1.23 2013/06/16 02:16:15 mdpetch Exp $
+ * $Id: gtkmovelistctrl.c,v 1.25 2014/07/20 21:03:22 plm Exp $
  */
 
 #include "config.h"
@@ -231,7 +231,7 @@ custom_cell_renderer_invalidate_size(void)
  * (Y - space)
  * (m - minus)
  */
-int _s_A, _s_A2, _s_B, _s_C, _s_D, _s_E, _s_Y, _s_Z, _s_ZP, _s_a, _s_b, _s_c, _s_cP, _s_d, _s_s, _s_m;
+static int _s_A, _s_A2, _s_B, _s_C, _s_D, _s_E, _s_Y, _s_Z, _s_ZP, _s_a, _s_b, _s_c, _s_cP, _s_d, _s_s, _s_m;
 
 static void
 custom_cell_renderer_movelist_get_size(GtkCellRenderer * cell,
@@ -241,7 +241,6 @@ custom_cell_renderer_movelist_get_size(GtkCellRenderer * cell,
 {
     gint calc_width;
     gint calc_height;
-    char buf[100];
     gfloat xalign, yalign;
 
     gtk_cell_renderer_get_alignment(cell, &xalign, &yalign);
@@ -250,6 +249,7 @@ custom_cell_renderer_movelist_get_size(GtkCellRenderer * cell,
         int l1Width, l2Width;
         PangoRectangle logical_rect;
         PangoLayout *layout;
+        char buf[100];
 
         sprintf(buf, "%.*f", fOutputDigits, 0.888888);
         layout = gtk_widget_create_pango_layout(widget, buf);
@@ -388,7 +388,7 @@ custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
     cmark_sz = cellprogress->pml->cmark ? "+" : "";
     highlight_sz = (phd->piHighlight && cellprogress->rank - 1 == *phd->piHighlight) ? "*" : "";
     if (cellprogress->rank > 0)
-        sprintf(buf, "%d%s%s", cellprogress->rank, cmark_sz, highlight_sz);
+        sprintf(buf, "%u%s%s", cellprogress->rank, cmark_sz, highlight_sz);
     else
         sprintf(buf, "??%s%s", cmark_sz, highlight_sz);
 
