@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtktoolbar.c,v 1.69 2013/06/16 02:16:17 mdpetch Exp $
+ * $Id: gtktoolbar.c,v 1.72 2014/07/20 21:15:07 plm Exp $
  */
 
 #include "config.h"
@@ -71,6 +71,7 @@ typedef struct _toolbarwidget {
 
 } toolbarwidget;
 
+#if (!USE_GTKUIMANAGER)
 static void
 ButtonClicked(GtkWidget * UNUSED(pw), char *sz)
 {
@@ -78,7 +79,6 @@ ButtonClicked(GtkWidget * UNUSED(pw), char *sz)
     UserCommand(sz);
 }
 
-
 static void
 ButtonClickedYesNo(GtkWidget * UNUSED(pw), char *sz)
 {
@@ -95,7 +95,6 @@ ButtonClickedYesNo(GtkWidget * UNUSED(pw), char *sz)
 
 }
 
-
 static GtkWidget *
 toggle_button_from_images(GtkWidget * pwImageOff, GtkWidget * pwImageOn, char *sz)
 {
@@ -123,6 +122,7 @@ toggle_button_from_images(GtkWidget * pwImageOff, GtkWidget * pwImageOn, char *s
     return pw;
 
 }
+#endif
 
 extern void
 ToolbarSetPlaying(GtkWidget * pwToolbar, const int f)
@@ -152,7 +152,7 @@ ToolbarSetClockwise(GtkWidget * pwToolbar, const int f)
 
 #if (USE_GTKUIMANAGER)
 extern void
-ToggleClockwise(GtkToggleAction * action, gpointer user_data)
+ToggleClockwise(GtkToggleAction * action, gpointer UNUSED(user_data))
 {
     int f = gtk_toggle_action_get_active(action);
     toolbarwidget *ptw = g_object_get_data(G_OBJECT(pwToolbar), "toolbarwidget");
@@ -207,7 +207,7 @@ ToolbarToggleClockwise(GtkWidget * pw, toolbarwidget * UNUSED(ptw))
 }
 #endif
 
-int editing = FALSE;
+static int editing = FALSE;
 
 extern void
 click_edit(void)
@@ -226,7 +226,7 @@ click_edit(void)
 
 #if (USE_GTKUIMANAGER)
 extern void
-ToggleEdit(GtkToggleAction * action, gpointer user_data)
+ToggleEdit(GtkToggleAction * action, gpointer UNUSED(user_data))
 {
     BoardData *pbd = BOARD(pwBoard)->board_data;
 
@@ -323,6 +323,7 @@ ToolbarUpdate(GtkWidget * pwToolbar,
     return c;
 }
 
+#if (!USE_GTKUIMANAGER)
 static GtkWidget *
 ToolbarAddButton(GtkToolbar * pwToolbar, const char *stockID, const char *label, const char *tooltip,
                  GCallback callback, void *data)
@@ -337,6 +338,7 @@ ToolbarAddButton(GtkToolbar * pwToolbar, const char *stockID, const char *label,
 
     return GTK_WIDGET(but);
 }
+#endif
 
 GtkWidget *
 ToolbarAddWidget(GtkToolbar * pwToolbar, GtkWidget * pWidget, const char *tooltip)
@@ -350,12 +352,14 @@ ToolbarAddWidget(GtkToolbar * pwToolbar, GtkWidget * pWidget, const char *toolti
     return GTK_WIDGET(ti);
 }
 
+#if (!USE_GTKUIMANAGER)
 static void
 ToolbarAddSeparator(GtkToolbar * pwToolbar)
 {
     GtkToolItem *sep = gtk_separator_tool_item_new();
     gtk_toolbar_insert(GTK_TOOLBAR(pwToolbar), sep, -1);
 }
+#endif
 
 extern GtkWidget *
 ToolbarNew(void)
@@ -377,21 +381,21 @@ ToolbarNew(void)
     gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwSave), TRUE);
     gtk_tool_button_set_label(GTK_TOOL_BUTTON(ptw->pwSave), NULL);
     ptw->pwTake = gtk_ui_manager_get_widget(puim, "/MainToolBar/Accept");
-    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwTake), FALSE);
+    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwTake), TRUE);
     ptw->pwDrop = gtk_ui_manager_get_widget(puim, "/MainToolBar/Reject");
-    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwDrop), FALSE);
+    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwDrop), TRUE);
     ptw->pwDouble = gtk_ui_manager_get_widget(puim, "/MainToolBar/Double");
-    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwDouble), FALSE);
+    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwDouble), TRUE);
     ptw->pwResign = gtk_ui_manager_get_widget(puim, "/MainToolBar/Resign");
-    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwResign), FALSE);
+    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwResign), TRUE);
     ptw->pwEndGame = gtk_ui_manager_get_widget(puim, "/MainToolBar/EndGame");
     gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwEndGame), FALSE);
     ptw->pwReset = gtk_ui_manager_get_widget(puim, "/MainToolBar/Undo");
-    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwReset), FALSE);
+    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwReset), TRUE);
     ptw->pwHint = gtk_ui_manager_get_widget(puim, "/MainToolBar/Hint");
-    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwHint), FALSE);
+    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwHint), TRUE);
     ptw->pwEdit = gtk_ui_manager_get_widget(puim, "/MainToolBar/EditPosition");
-    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwEdit), FALSE);
+    gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwEdit), TRUE);
     gtk_tool_button_set_label(GTK_TOOL_BUTTON(ptw->pwEdit), NULL);
     ptw->pwButtonClockwise = gtk_ui_manager_get_widget(puim, "/MainToolBar/PlayClockwise");
     gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwButtonClockwise), FALSE);
@@ -563,6 +567,7 @@ ToolbarNew(void)
 #endif
 }
 
+#if (!USE_GTKUIMANAGER)
 static GtkWidget *
 firstChild(GtkWidget * widget)
 {
@@ -601,6 +606,7 @@ SetToolbarItemStyle(gpointer data, gpointer user_data)
     else
         gtk_widget_hide(text);
 }
+#endif
 
 extern void
 SetToolbarStyle(int value)
