@@ -15,7 +15,7 @@
  * cache.c
  *
  * by Gary Wong, 1997-2000
- * $Id: cache.c,v 1.35 2013/06/16 02:16:23 mdpetch Exp $
+ * $Id: cache.c,v 1.39 2015/01/11 15:59:39 plm Exp $
  */
 
 #include "config.h"
@@ -93,149 +93,46 @@ CacheCreate(evalCache * pc, unsigned int s)
     return 0;
 }
 
-/*
- * 
- * from http://burtleburtle.net/bob/c/lookup3.c
- * 
- * -------------------------------------------------------------------------------
- * lookup3.c, by Bob Jenkins, May 2006, Public Domain.
- * 
- * These are functions for producing 32-bit hashes for hash table lookup.
- * hashword(), hashlittle(), hashlittle2(), hashbig(), mix(), and final() 
- * are externally useful functions.  Routines to test the hash are included 
- * if SELF_TEST is defined.  You can use this free for any purpose.  It's in
- * the public domain.  It has no warranty.
- * [...]
- * If you want to find a hash of, say, exactly 7 integers, do
- * a = i1;  b = i2;  c = i3;
- * mix(a,b,c);
- * a += i4; b += i5; c += i6;
- * mix(a,b,c);
- * a += i7;
- * final(a,b,c);
- * then use c as the hash value.
- * [...]
- * -------------------------------------------------------------------------------
- */
-
-#define rot(x,k) (((x)<<(k)) | ((x)>>(32-(k))))
-
-/*
- * -------------------------------------------------------------------------------
- * mix -- mix 3 32-bit values reversibly.
- * 
- * This is reversible, so any information in (a,b,c) before mix() is
- * still in (a,b,c) after mix().
- * 
- * If four pairs of (a,b,c) inputs are run through mix(), or through
- * mix() in reverse, there are at least 32 bits of the output that
- * are sometimes the same for one pair and different for another pair.
- * This was tested for:
- * * pairs that differed by one bit, by two bits, in any combination
- * of top bits of (a,b,c), or in any combination of bottom bits of
- * (a,b,c).
- * * "differ" is defined as +, -, ^, or ~^.  For + and -, I transformed
- * the output delta to a Gray code (a^(a>>1)) so a string of 1's (as
- * is commonly produced by subtraction) look like a single 1-bit
- * difference.
- * * the base values were pseudorandom, all zero but one bit set, or 
- * all zero plus a counter that starts at zero.
- * 
- * Some k values for my "a-=c; a^=rot(c,k); c+=b;" arrangement that
- * satisfy this are
- * 4  6  8 16 19  4
- * 9 15  3 18 27 15
- * 14  9  3  7 17  3
- * Well, "9 15 3 18 27 15" didn't quite get 32 bits diffing
- * for "differ" defined as + with a one-bit base and a two-bit delta.  I
- * used http://burtleburtle.net/bob/hash/avalanche.html to choose 
- * the operations, constants, and arrangements of the variables.
- * 
- * This does not achieve avalanche.  There are input bits of (a,b,c)
- * that fail to affect some output bits of (a,b,c), especially of a.  The
- * most thoroughly mixed value is c, but it doesn't really even achieve
- * avalanche in c.
- * 
- * This allows some parallelism.  Read-after-writes are good at doubling
- * the number of bits affected, so the goal of mixing pulls in the opposite
- * direction as the goal of parallelism.  I did what I could.  Rotates
- * seem to cost as much as shifts on every machine I could lay my hands
- * on, and rotates are much kinder to the top and bottom bits, so I used
- * rotates.
- * -------------------------------------------------------------------------------
- */
-#define mix(a,b,c) \
-{ \
-  a -= c;  a ^= rot(c, 4);  c += b; \
-  b -= a;  b ^= rot(a, 6);  a += c; \
-  c -= b;  c ^= rot(b, 8);  b += a; \
-  a -= c;  a ^= rot(c,16);  c += b; \
-  b -= a;  b ^= rot(a,19);  a += c; \
-  c -= b;  c ^= rot(b, 4);  b += a; \
-}
-
-/*
- * -------------------------------------------------------------------------------
- * final -- final mixing of 3 32-bit values (a,b,c) into c
- * 
- * Pairs of (a,b,c) values differing in only a few bits will usually
- * produce values of c that look totally different.  This was tested for
- * * pairs that differed by one bit, by two bits, in any combination
- * of top bits of (a,b,c), or in any combination of bottom bits of
- * (a,b,c).
- * * "differ" is defined as +, -, ^, or ~^.  For + and -, I transformed
- * the output delta to a Gray code (a^(a>>1)) so a string of 1's (as
- * is commonly produced by subtraction) look like a single 1-bit
- * difference.
- * * the base values were pseudorandom, all zero but one bit set, or 
- * all zero plus a counter that starts at zero.
- * 
- * These constants passed:
- * 14 11 25 16 4 14 24
- * 12 14 25 16 4 14 24
- * and these came close:
- * 4  8 15 26 3 22 24
- * 10  8 15 26 3 22 24
- * 11  8 15 26 3 22 24
- * -------------------------------------------------------------------------------
- */
-#define final(a,b,c) \
-{ \
-  c ^= b; c -= rot(b,14); \
-  a ^= c; a -= rot(c,11); \
-  b ^= a; b -= rot(a,25); \
-  c ^= b; c -= rot(b,16); \
-  a ^= c; a -= rot(c,4);  \
-  b ^= a; b -= rot(a,14); \
-  c ^= b; c -= rot(b,24); \
-}
+/* MurmurHash3  https://code.google.com/p/smhasher/wiki/MurmurHash */
 
 extern uint32_t
 GetHashKey(uint32_t hashMask, const cacheNodeDetail * e)
 {
-    uint32_t a, b, c;
+    uint32_t hash = (uint32_t) e->nEvalContext;
+    int i;
 
-    a = b = c = 0xdeadbeef + (uint32_t) e->nEvalContext;
+    hash *= 0xcc9e2d51;
+    hash = (hash << 15) | (hash >> (32 - 15));
+    hash *= 0x1b873593;
 
-    a = a + e->key.data[0];
-    b = b + e->key.data[1];
-    c = c + e->key.data[2];
+    hash = (hash << 13) | (hash >> (32 - 13));
+    hash = hash * 5 + 0xe6546b64;
 
-    mix(a, b, c);
+    for (i = 0; i < 7; i++) {
+        uint32_t k = e->key.data[i];
 
-    a = a + e->key.data[3];
-    b = b + e->key.data[4];
-    b = b + e->key.data[5];
+        k *= 0xcc9e2d51;
+        k = (k << 15) | (k >> (32 - 15));
+        k *= 0x1b873593;
 
-    mix(a, b, c);
+        hash ^= k;
+        hash = (hash << 13) | (hash >> (32 - 13));
+        hash = hash * 5 + 0xe6546b64;
+    }
 
-    a = a + e->key.data[6];
+    /* Real MurmurHash3 has a "hash ^= len" here,
+     * but for us len is constant. Skip it */
 
-    final(a, b, c);
+    hash ^= hash >> 16;
+    hash *= 0x85ebca6b;
+    hash ^= hash >> 13;
+    hash *= 0xc2b2ae35;
+    hash ^= hash >> 16;
 
-    return (c & hashMask);
+    return (hash & hashMask);
 }
 
+
 uint32_t
 CacheLookupWithLocking(evalCache * pc, const cacheNodeDetail * e, float *arOut, float *arCubeful)
 {
@@ -261,10 +158,6 @@ CacheLookupWithLocking(evalCache * pc, const cacheNodeDetail * e, float *arOut,
         }
     }
     /* Cache hit */
-#if CACHE_STATS
-    ++pc->cHit;
-#endif
-
     memcpy(arOut, pc->entries[l].nd_primary.ar, sizeof(float) * 5 /*NUM_OUTPUTS */ );
     if (arCubeful)
         *arCubeful = pc->entries[l].nd_primary.ar[5];   /* Cubeful equity stored in slot 5 */
@@ -273,6 +166,10 @@ CacheLookupWithLocking(evalCache * pc, const cacheNodeDetail * e, float *arOut,
     cache_unlock(pc, l);
 #endif
 
+#if CACHE_STATS
+    ++pc->cHit;
+#endif
+
     return CACHEHIT;
 }
 
@@ -294,15 +191,16 @@ CacheLookupNoLocking(evalCache * pc, const cacheNodeDetail * e, float *arOut, fl
             pc->entries[l].nd_secondary = tmp;
         }
     }
-    /* Cache hit */
-#if CACHE_STATS
-    ++pc->cHit;
-#endif
 
+    /* Cache hit */
     memcpy(arOut, pc->entries[l].nd_primary.ar, sizeof(float) * 5 /*NUM_OUTPUTS */ );
     if (arCubeful)
         *arCubeful = pc->entries[l].nd_primary.ar[5];   /* Cubeful equity stored in slot 5 */
 
+#if CACHE_STATS
+    ++pc->cHit;
+#endif
+
     return CACHEHIT;
 }
 
@@ -336,8 +234,8 @@ CacheFlush(const evalCache * pc)
 {
     unsigned int k;
     for (k = 0; k < pc->size / 2; ++k) {
-        pc->entries[k].nd_primary.nEvalContext = -1;
-        pc->entries[k].nd_secondary.nEvalContext = -1;
+        pc->entries[k].nd_primary.key.data[0] = (unsigned int) -1;
+        pc->entries[k].nd_secondary.key.data[0] = (unsigned int) -1;
 #if USE_MULTITHREAD
         pc->entries[k].lock = 0;
 #endif
