@@ -22,7 +22,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: md5.c,v 1.13 2014/05/11 15:20:32 plm Exp $
+ * $Id: md5.c,v 1.14 2014/12/21 22:33:22 plm Exp $
  */
 
 /* License changed from the GNU LGPL to the GNU GPL (as permitted
@@ -43,10 +43,10 @@
       ( (unsigned char *) (p) )[ 3 ] = ( (n) & 0xFF000000 ) >> 24 )
 
 #define READ( p ) \
-    ( ( (unsigned char *) (p) )[ 0 ] | \
-      ( (unsigned int)((unsigned char *) (p) )[ 1 ]) << 8 | \
-      ( (unsigned int)((unsigned char *) (p) )[ 2 ]) << 16 | \
-      ( (unsigned int)((unsigned char *) (p) )[ 3 ]) << 24 )
+    ( ( (const unsigned char *) (p) )[ 0 ] | \
+      ( (unsigned int)((const unsigned char *) (p) )[ 1 ]) << 8 | \
+      ( (unsigned int)((const unsigned char *) (p) )[ 2 ]) << 16 | \
+      ( (unsigned int)((const unsigned char *) (p) )[ 3 ]) << 24 )
 
 /* This array contains the bytes used to pad the buffer to the next
  * 64-byte boundary.  (RFC 1321, 3.1: Step 1)  */
