@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: neuralnet.c,v 1.80 2013/07/20 22:06:24 mdpetch Exp $
+ * $Id: neuralnet.c,v 1.85 2014/11/23 20:17:48 plm Exp $
  */
 
 #include "config.h"
@@ -34,6 +34,56 @@
 #include "simd.h"
 #include "sigmoid.h"
 
+extern int
+NeuralNetCreate(neuralnet * pnn, unsigned int cInput, unsigned int cHidden,
+                unsigned int cOutput, float rBetaHidden, float rBetaOutput)
+{
+    pnn->cInput = cInput;
+    pnn->cHidden = cHidden;
+    pnn->cOutput = cOutput;
+    pnn->rBetaHidden = rBetaHidden;
+    pnn->rBetaOutput = rBetaOutput;
+    pnn->nTrained = 0;
+
+    if ((pnn->arHiddenWeight = sse_malloc(cHidden * cInput * sizeof(float))) == NULL)
+        return -1;
+
+    if ((pnn->arOutputWeight = sse_malloc(cOutput * cHidden * sizeof(float))) == NULL) {
+        sse_free(pnn->arHiddenWeight);
+        return -1;
+    }
+
+    if ((pnn->arHiddenThreshold = sse_malloc(cHidden * sizeof(float))) == NULL) {
+        sse_free(pnn->arOutputWeight);
+        sse_free(pnn->arHiddenWeight);
+        return -1;
+    }
+
+    if ((pnn->arOutputThreshold = sse_malloc(cOutput * sizeof(float))) == NULL) {
+        sse_free(pnn->arHiddenThreshold);
+        sse_free(pnn->arOutputWeight);
+        sse_free(pnn->arHiddenWeight);
+        return -1;
+    }
+
+    return 0;
+}
+
+extern void
+NeuralNetDestroy(neuralnet * pnn)
+{
+    sse_free(pnn->arHiddenWeight);
+    pnn->arHiddenWeight = 0;
+    sse_free(pnn->arOutputWeight);
+    pnn->arOutputWeight = 0;
+    sse_free(pnn->arHiddenThreshold);
+    pnn->arHiddenThreshold = 0;
+    sse_free(pnn->arOutputThreshold);
+    pnn->arOutputThreshold = 0;
+}
+
+#if !defined(USE_SIMD_INSTRUCTIONS)
+
 /* separate context for race, crashed, contact
  * -1: regular eval
  * 0: save base
@@ -70,57 +120,6 @@ NNevalAction(NNState * pnState)
     return NNEVAL_NONE;         /* for the picky compiler */
 }
 
-extern int
-NeuralNetCreate(neuralnet * pnn, unsigned int cInput, unsigned int cHidden,
-                unsigned int cOutput, float rBetaHidden, float rBetaOutput)
-{
-    pnn->cInput = cInput;
-    pnn->cHidden = cHidden;
-    pnn->cOutput = cOutput;
-    pnn->rBetaHidden = rBetaHidden;
-    pnn->rBetaOutput = rBetaOutput;
-    pnn->nTrained = 0;
-    pnn->fDirect = FALSE;
-
-    if ((pnn->arHiddenWeight = sse_malloc(cHidden * cInput * sizeof(float))) == NULL)
-        return -1;
-
-    if ((pnn->arOutputWeight = sse_malloc(cOutput * cHidden * sizeof(float))) == NULL) {
-        sse_free(pnn->arHiddenWeight);
-        return -1;
-    }
-
-    if ((pnn->arHiddenThreshold = sse_malloc(cHidden * sizeof(float))) == NULL) {
-        sse_free(pnn->arOutputWeight);
-        sse_free(pnn->arHiddenWeight);
-        return -1;
-    }
-
-    if ((pnn->arOutputThreshold = sse_malloc(cOutput * sizeof(float))) == NULL) {
-        sse_free(pnn->arHiddenThreshold);
-        sse_free(pnn->arOutputWeight);
-        sse_free(pnn->arHiddenWeight);
-        return -1;
-    }
-
-    return 0;
-}
-
-extern void
-NeuralNetDestroy(neuralnet * pnn)
-{
-    if (!pnn->fDirect) {
-        sse_free(pnn->arHiddenWeight);
-        pnn->arHiddenWeight = 0;
-        sse_free(pnn->arOutputWeight);
-        pnn->arOutputWeight = 0;
-        sse_free(pnn->arHiddenThreshold);
-        pnn->arHiddenThreshold = 0;
-        sse_free(pnn->arOutputThreshold);
-        pnn->arOutputThreshold = 0;
-    }
-}
-
 static void
 Evaluate(const neuralnet * pnn, const float arInput[], float ar[], float arOutput[], float *saveAr)
 {
@@ -137,7 +136,7 @@ Evaluate(const neuralnet * pnn, const float arInput[], float ar[], float arOutpu
     for (i = 0; i < pnn->cInput; i++) {
         float const ari = arInput[i];
 
-        if (!ari)
+        if (ari == 0.0f)
             prWeight += cHidden;
         else {
             float *pr = ar;
@@ -185,7 +184,7 @@ EvaluateFromBase(const neuralnet * pnn, const float arInputDif[], float ar[], fl
     for (i = 0; i < pnn->cInput; ++i) {
         float const ari = arInputDif[i];
 
-        if (!ari)
+        if (ari == 0.0f)
             prWeight += pnn->cHidden;
         else {
             float *pr = ar;
@@ -230,9 +229,7 @@ NeuralNetEvaluate(const neuralnet * pnn, float arInput[], float arOutput[], NNSt
         }
     case NNEVAL_SAVE:
         {
-#if !USE_SIMD_INSTRUCTIONS
             pnState->cSavedIBase = pnn->cInput;
-#endif
             memcpy(pnState->savedIBase, arInput, pnn->cInput * sizeof(*ar));
             Evaluate(pnn, arInput, ar, arOutput, pnState->savedBase);
             break;
@@ -240,12 +237,10 @@ NeuralNetEvaluate(const neuralnet * pnn, float arInput[], float arOutput[], NNSt
     case NNEVAL_FROMBASE:
         {
             unsigned int i;
-#if !USE_SIMD_INSTRUCTIONS
-            if (pnState->cSavedIBase != pnn->cInput){
+            if (pnState->cSavedIBase != (int) pnn->cInput) {
                 Evaluate(pnn, arInput, ar, arOutput, 0);
                 break;
             }
-#endif
             memcpy(ar, pnState->savedBase, pnn->cHidden * sizeof(*ar));
 
             {
@@ -266,6 +261,7 @@ NeuralNetEvaluate(const neuralnet * pnn, float arInput[], float arOutput[], NNSt
     }
     return 0;
 }
+#endif
 
 extern int
 NeuralNetLoad(neuralnet * pnn, FILE * pf)
@@ -366,7 +362,7 @@ NeuralNetSaveBinary(const neuralnet * pnn, FILE * pf)
 }
 
 
-#if USE_SIMD_INSTRUCTIONS
+#if defined(USE_SIMD_INSTRUCTIONS)
 
 #if defined(DISABLE_SIMD_TEST)
 
@@ -383,7 +379,7 @@ SIMD_Supported(void)
 #endif
 
 static int
-check_for_cpuid()
+check_for_cpuid(void)
 {
     int result;
 
@@ -565,4 +561,3 @@ SIMD_Supported(void)
 
 #endif
 #endif
-
