@@ -16,13 +16,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: makebearoff.c,v 1.89 2013/07/10 23:32:50 mdpetch Exp $
+ * $Id: makebearoff.c,v 1.96 2014/12/03 15:43:37 plm Exp $
  */
 
 #include "config.h"
 
-#include <glib.h>
-#include <glib/gstdio.h>
 #include <stdio.h>
 #ifdef WIN32
 #include <io.h>
@@ -39,6 +37,8 @@
 #include "bearoff.h"
 #include "util.h"
 #include "backgammon.h"
+#include <glib/gstdio.h>
+#include "glib-ext.h"
 #include "multithread.h"
 
 void
@@ -61,7 +61,7 @@ typedef struct _xhash {
 
 static long cLookup;
 
-static long int
+static int
 XhashPosition(xhash * ph, const int iKey)
 {
 
@@ -75,7 +75,7 @@ XhashStatus(xhash * ph)
 
     fprintf(stderr, "Xhash status:\n");
     fprintf(stderr, "Size:    %d elements\n", ph->nHashSize);
-    fprintf(stderr, "Queries: %lu (hits: %ld)\n", ph->nQueries, ph->nHits);
+    fprintf(stderr, "Queries: %lu (hits: %lu)\n", ph->nQueries, ph->nHits);
     fprintf(stderr, "Entries: %lu (overwrites: %lu)\n", ph->nEntries, ph->nOverwrites);
 
 }
@@ -169,15 +169,13 @@ OSLookup(const unsigned int iPos,
          unsigned short int aProb[64], const int fGammon, const int fCompress, FILE * pfOutput, FILE * pfTmp)
 {
 
-    int i, j;
+    unsigned int i, j;
     unsigned char ac[128];
 
     g_assert(pfOutput != stdin);
 
     if (fCompress) {
 
-        unsigned char ac[128];
-        unsigned int i, j;
         long iOffset;
         size_t nBytes;
         unsigned int ioff, nz, ioffg = 0, nzg = 0;
@@ -241,13 +239,13 @@ OSLookup(const unsigned int iPos,
 
         i = 0;
         for (j = 0; j < nz; ++j, i += 2) {
-            us = ac[i] | ac[i + 1] << 8;
+            us = (unsigned short) (ac[i] | ac[i + 1] << 8);
             aProb[ioff + j] = us;
         }
 
         /* if ( fGammon ) */
         for (j = 0; j < nzg; ++j, i += 2) {
-            us = ac[i] | ac[i + 1] << 8;
+            us = (unsigned short) (ac[i] | ac[i + 1] << 8);
             aProb[32 + ioffg + j] = us;
         }
 
@@ -278,11 +276,11 @@ OSLookup(const unsigned int iPos,
 
         i = 0;
         for (j = 0; j < 32; ++j, i += 2)
-            aProb[j] = ac[i] | ac[i + 1] << 8;
+            aProb[j] = (unsigned short) (ac[i] | ac[i + 1] << 8);
 
         if (fGammon)
             for (j = 0; j < 32; ++j, i += 2)
-                aProb[j + 32] = ac[i] | ac[i + 1] << 8;
+                aProb[j + 32] = (unsigned short) (ac[i] | ac[i + 1] << 8);
 
         /* position cursor at end of file */
 
@@ -483,7 +481,7 @@ BearOff(int nId, unsigned int nPoints,
         }
 
     for (i = 0, j = 0, iMode = 0; i < 32; i++) {
-        j += (aOutProb[i] = (aProb[i] + 18) / 36);
+        j += (aOutProb[i] = (unsigned short) ((aProb[i] + 18) / 36));
         if (aOutProb[i] > aOutProb[iMode])
             iMode = i;
     }
@@ -494,7 +492,7 @@ BearOff(int nId, unsigned int nPoints,
 
     if (fGammon) {
         for (i = 0, j = 0, iMode = 0; i < 32; i++) {
-            j += (aOutProb[32 + i] = (aProb[32 + i] + 18) / 36);
+            j += (aOutProb[32 + i] = (unsigned short) ((aProb[32 + i] + 18) / 36));
             if (aOutProb[32 + i] > aOutProb[32 + iMode])
                 iMode = i;
         }
@@ -563,9 +561,9 @@ WriteFloat(const float r, FILE * output)
 {
 
     int j;
-    unsigned char *pc;
+    const unsigned char *pc;
 
-    pc = (unsigned char *) &r;
+    pc = (const unsigned char *) &r;
 
     for (j = 0; j < 4; ++j)
         putc(*(pc++), output);
@@ -659,7 +657,7 @@ generate_os(const int nOS, const int fHeader,
     if (fCompress) {
 
         char ac[256];
-        unsigned int n;
+        size_t n;
         /* write contents of pfTmp to output */
 
         rewind(pfTmp);
@@ -819,17 +817,15 @@ NDBearoff(const int iPos, const unsigned int nPoints, float ar[4], xhash * ph, b
 
         }
 
-
     ar[0] /= 36.0f;
-    ar[1] = sqrt(rVarSum / 36.0f - ar[0] * ar[0]);
+    ar[1] = sqrtf(rVarSum / 36.0f - ar[0] * ar[0]);
 
     ar[2] /= 36.0f;
-    ar[3] = sqrt(rGammonVarSum / 36.0f - ar[2] * ar[2]);
+    ar[3] = sqrtf(rGammonVarSum / 36.0f - ar[2] * ar[2]);
 
 }
 
 
-
 static void
 generate_nd(const int nPoints, const int nHashSize, const int fHeader, bearoffcontext * pbc, FILE * output)
 {
@@ -962,7 +958,7 @@ TSLookup(const int nUs, const int nThem,
     }
 
     for (i = 0; i < (fCubeful ? 4 : 1); ++i) {
-        us = ac[2 * i] | ac[2 * i + 1] << 8;
+        us = (unsigned short) (ac[2 * i] | ac[2 * i + 1] << 8);
         arEquity[i] = us - 0x8000;
     }
 
@@ -1024,8 +1020,8 @@ BearOff2(int nUs, int nThem,
     /* look for position in bearoff file */
 
     if (pbc && isBearoff(pbc, (ConstTanBoard) anBoard)) {
-        unsigned short int nUsL = PositionBearoff(anBoard[1], pbc->nPoints, pbc->nChequers);
-        unsigned short int nThemL = PositionBearoff(anBoard[0], pbc->nPoints, pbc->nChequers);
+        unsigned short int nUsL = (unsigned short) PositionBearoff(anBoard[1], pbc->nPoints, pbc->nChequers);
+        unsigned short int nThemL = (unsigned short) PositionBearoff(anBoard[0], pbc->nPoints, pbc->nChequers);
         int nL = Combination(pbc->nPoints + pbc->nChequers, pbc->nPoints);
         unsigned int iPos = nUsL * nL + nThemL;
         unsigned short int aus[4];
@@ -1121,7 +1117,7 @@ BearOff2(int nUs, int nThem,
 
     /* final equities */
     for (k = 0; k < (fCubeful ? 4 : 1); ++k)
-        asiEquity[k] = aiTotal[k] / 36;
+        asiEquity[k] = (short) (aiTotal[k] / 36);
 
 }
 
@@ -1255,7 +1251,7 @@ generate_ts(const int nTSP, const int nTSC,
 static void
 version(void)
 {
-    printf("makebearoff $Revision: 1.89 $\n");
+    printf("makebearoff $Revision: 1.96 $\n");
 }
 
 
@@ -1275,7 +1271,8 @@ main(int argc, char **argv)
     static char *szTwoSided = NULL;
     static int show_version = 0;
 
-    MT_InitThreads(); 
+    glib_ext_init();
+    MT_InitThreads();
     bearoffcontext *pbc = NULL;
     FILE *output;
     double r;
@@ -1321,7 +1318,7 @@ main(int argc, char **argv)
 
 
     if (szTwoSided)
-        sscanf(szTwoSided, "%dx%d", &nTSP, &nTSC);
+        sscanf(szTwoSided, "%2dx%2d", &nTSP, &nTSC);
 
     if (show_version) {
         version();
@@ -1349,7 +1346,7 @@ main(int argc, char **argv)
         fprintf(stderr, "%-37s\n", _("One-sided database"));
         fprintf(stderr, "%-37s: %12d\n", _("Number of points"), nOS);
         fprintf(stderr, "%-37s: %12d\n", _("Number of chequers"), 15);
-        fprintf(stderr, "%-37s: %12d\n", _("Number of positions"), Combination(nOS + 15, nOS));
+        fprintf(stderr, "%-37s: %12u\n", _("Number of positions"), Combination(nOS + 15, nOS));
         fprintf(stderr, "%-37s: %12s\n", _("Approximate by normal distribution"), fND ? _("yes") : _("no"));
         fprintf(stderr, "%-37s: %12s\n", _("Include gammon distributions"), fGammon ? _("yes") : _("no"));
         fprintf(stderr, "%-37s: %12s\n", _("Use compression scheme"), fCompress ? _("yes") : _("no"));
@@ -1389,10 +1386,7 @@ main(int argc, char **argv)
             generate_os(nOS, fHeader, fCompress, fGammon, nHashSize, pbc, output);
         }
 
-        if (pbc) {
-            fprintf(stderr, "Number of reads in old database: %lu\n", pbc->nReads);
-            BearoffClose(pbc);
-        }
+        BearoffClose(pbc);
 
         fprintf(stderr, "Number of re-reads while generating: %ld\n", cLookup);
     }
@@ -1437,10 +1431,8 @@ main(int argc, char **argv)
 
         /* close old bearoff database */
 
-        if (pbc) {
-            fprintf(stderr, "Number of reads in old database: %lu\n", pbc->nReads);
-            BearoffClose(pbc);
-        }
+        BearoffClose(pbc);
+
         fprintf(stderr, "Number of re-reads while generating: %ld\n", cLookup);
 
     }
@@ -1449,12 +1441,3 @@ main(int argc, char **argv)
     return 0;
 
 }
-
-extern bearoffcontext *
-BearoffInitBuiltin(void)
-{
-
-    printf("Make makebearoff build (avoid resursive rules Makefile :-)\n");
-    return NULL;
-
-}
