@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: makehyper.c,v 1.41 2013/07/10 19:21:45 mdpetch Exp $
+ * $Id: makehyper.c,v 1.47 2015/04/12 22:13:49 plm Exp $
  */
 
 #include "config.h"
@@ -29,16 +29,14 @@
 #include <time.h>
 #include <unistd.h>
 #include <math.h>
-#include <multithread.h>
-#include "backgammon.h"
+#include <locale.h>
 
+#include "backgammon.h"
 #include "eval.h"
 #include "positionid.h"
-#include <locale.h>
 #include "bearoff.h"
-#include "drawboard.h"
-#include "multithread.h"
 #include "lib/simd.h"
+#include "glib-ext.h"
 #include "multithread.h"
 
 static cubeinfo ci;
@@ -72,8 +70,7 @@ MT_CloseThreads(void)
     return;
 }
 
-int aiNorm[10];
-
+static int aiNorm[10];
 
 static hyperclass
 ClassifyHyper(TanBoard anBoard)
@@ -592,13 +589,13 @@ main(int argc, char **argv)
         {"restart", 'r', 0, G_OPTION_ARG_FILENAME, &szRestart,
          "Restart calculation of database from \"filename\"", "filename"},
         {"threshold", 't', 0, G_OPTION_ARG_STRING, &szEpsilon,
-         "The convergens threshold (T). Default is 1e-5", "T"},
+         "The convergence threshold (T). Default is 1e-5", "T"},
         {"no-checkpoint", 'n', G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &fCheckPoint,
          "Do not write a checkpoint file after each iteration.", NULL},
         {"version", 'v', 0, G_OPTION_ARG_NONE, &show_version,
          "Print version info and exit", NULL},
         {"outfile", 'f', 0, G_OPTION_ARG_STRING, &szOutput,
-         "Required output filename", "filename"},
+         "Output filename. Default is hyper<C>.bd.", "filename"},
         {NULL, 0, 0, 0, NULL, NULL, NULL}
     };
 
@@ -607,6 +604,7 @@ main(int argc, char **argv)
 
     /* i18n */
 
+    glib_ext_init();
     MT_InitThreads();
     setlocale(LC_ALL, "");
     bindtextdomain(PACKAGE, LOCALEDIR);
@@ -635,11 +633,14 @@ main(int argc, char **argv)
         exit(1);
     }
 
-    if (!szOutput || nC < 1 || nC > 3) {
+    if (nC < 1 || nC > 3) {
         g_printerr("Illegal options. Try `makehyper --help' for usage " "information\n");
         exit(1);
     }
 
+    if (!szOutput)
+        szOutput = g_strdup_printf("hyper%d.bd", nC);
+
     /* start calculation */
 
     time(&t2);
@@ -652,7 +653,7 @@ main(int argc, char **argv)
     printf("%-40s: %d\n", _("Total number of two sided positions"), nPos * nPos);
     printf("%-40s: %s %d\n", _("Estimated size of file"), _("bytes"), nPos * nPos * 28 + 40);
     printf("%-40s: %s\n", _("Output file"), szOutput);
-    printf("%-40s: %e\n", _("Convergens threshold"), rEpsilon);
+    printf("%-40s: %e\n", _("Convergence threshold"), rEpsilon);
 
     /* Iteration 0 */
 
