@@ -12,7 +12,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: multithread.h,v 1.52 2013/07/10 22:35:13 mdpetch Exp $
+ * $Id: multithread.h,v 1.54 2014/07/26 06:23:35 mdpetch Exp $
  */
 
 #ifndef MULTITHREAD_H
@@ -31,6 +31,8 @@
 
 #include "backgammon.h"
 
+#define UI_UPDATETIME 250
+
 /*#define DEBUG_MULTITHREADED 1 */
 #if defined (USE_MULTITHREAD) && defined(DEBUG_MULTITHREADED)
 void multi_debug(const char *str, ...);
@@ -67,14 +69,14 @@ typedef struct _ManualEvent {
 #endif
     int signalled;
 } *ManualEvent;
-typedef GPrivate* TLSItem;
+typedef GPrivate *TLSItem;
 
 #if GLIB_CHECK_VERSION (2,32,0)
 typedef GMutex Mutex;
 #else
 typedef GMutex *Mutex;
 #endif
-#elif defined(WIN32) /* GLIB_THREAD */
+#elif defined(WIN32)            /* GLIB_THREAD */
 typedef HANDLE ManualEvent;
 typedef DWORD TLSItem;
 typedef HANDLE Event;
@@ -140,8 +142,8 @@ extern ThreadData td;
 
 #if defined(GLIB_THREADS)
 extern void ResetManualEvent(ManualEvent ME);
-extern void Mutex_Lock(Mutex mutex, const char *reason);
-extern void Mutex_Release(Mutex mutex);
+extern void Mutex_Lock(Mutex *mutex, const char *reason);
+extern void Mutex_Release(Mutex *mutex);
 extern void WaitForManualEvent(ManualEvent ME);
 extern void SetManualEvent(ManualEvent ME);
 extern void TLSSetValue(TLSItem pItem, size_t value);
@@ -150,16 +152,16 @@ extern void TLSFree(TLSItem pItem);
 extern void InitManualEvent(ManualEvent * pME);
 extern void FreeManualEvent(ManualEvent ME);
 extern void InitMutex(Mutex * pMutex);
-extern void FreeMutex(Mutex mutex);
+extern void FreeMutex(Mutex * mutex);
 
 #define UI_UPDATETIME 250
 
 #if defined (GLIB_THREADS)
 #define TLSGet(item) *((size_t*)g_private_get(item))
 
-#else /* WIN32 */
+#else                           /* WIN32 */
 #define TLSGet(item) *((int*)TlsGetValue(item))
-#endif /* GLIB_THREADS */
+#endif                          /* GLIB_THREADS */
 
 #if !defined(MAX_NUMTHREADS)
 #define MAX_NUMTHREADS 48
