@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: openurl.c,v 1.27 2013/06/16 02:16:19 mdpetch Exp $
+ * $Id: openurl.c,v 1.28 2013/07/22 23:04:00 mdpetch Exp $
  */
 #include "config.h"
 #include <stdio.h>
@@ -46,7 +46,7 @@ get_web_browser(void)
 #ifdef __APPLE__
         pch = "open";
 #else
-        pch = "firefox";
+        pch = OPEN_URL_PROG;
 #endif
     }
     return pch;
