@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: positionid.h,v 1.36 2013/06/16 02:16:19 mdpetch Exp $
+ * $Id: positionid.h,v 1.38 2014/10/07 07:14:29 plm Exp $
  */
 
 #ifndef POSITIONID_H
@@ -30,10 +30,13 @@ extern void PositionKey(const TanBoard anBoard, positionkey * pkey);
 extern char *PositionID(const TanBoard anBoard);
 extern char *PositionIDFromKey(const positionkey * pkey);
 
+extern int PositionFromXG(TanBoard anBoard, const char * pos);
+
 extern
 unsigned int PositionBearoff(const unsigned int anBoard[], unsigned int nPoints, unsigned int nChequers);
 
 extern void PositionFromKey(TanBoard anBoard, const positionkey * pkey);
+extern void PositionFromKeySwapped(TanBoard anBoard, const positionkey * pkey);
 
 /* Return 1 for success, 0 for invalid id */
 extern int PositionFromID(TanBoard anBoard, const char *szID);
