@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: renderprefs.c,v 1.45 2013/06/16 02:16:20 mdpetch Exp $
+ * $Id: renderprefs.c,v 1.51 2015/01/01 16:42:04 plm Exp $
  */
 
 #include "config.h"
@@ -43,7 +43,7 @@ const char *aszWoodName[] = {
     "oak", "pine", "redwood", "walnut", "willow", "paint"
 };
 
-renderdata rdAppearance;
+static renderdata rdAppearance;
 
 /* Limit use of global... */
 extern renderdata *
@@ -62,7 +62,7 @@ static char
 HexDigit(char ch)
 {
 
-    ch = toupper(ch);
+    ch = (char) toupper(ch);
 
     if (ch >= '0' && ch <= '9')
         return ch - '0';
@@ -84,7 +84,7 @@ SetColour(const char *sz, unsigned char anColour[])
     sz++;
 
     for (i = 0; i < 3; i++) {
-        anColour[i] = (HexDigit(sz[0]) << 4) | HexDigit(sz[1]);
+        anColour[i] = (char) (HexDigit(sz[0]) << 4) | HexDigit(sz[1]);
         sz += 2;
     }
 
@@ -113,7 +113,7 @@ SetColourSpeckle(const char *sz, unsigned char anColour[], int *pnSpeckle)
 
 /* Set colour (with floats) */
 static int
-SetColourX(gdouble arColour[4], const char *sz)
+SetColourX(float arColour[4], const char *sz)
 {
 
     char *pch;
@@ -159,7 +159,7 @@ static int
 SetMaterialCommon(Material * pMat, const char *sz, const char **arg)
 {
     float opac;
-    char *pch;
+    char *pch = NULL;
 
     if (SetColourF(pMat->ambientColour, sz) != 0)
         return -1;
@@ -172,20 +172,21 @@ SetMaterialCommon(Material * pMat, const char *sz, const char **arg)
     if (SetColourF(pMat->specularColour, sz) != 0)
         return -1;
 
-    if (sz)
+    if (sz) {
         sz += strlen(sz) + 1;
-    if ((pch = strchr(sz, ';')))
-        *pch = 0;
-
+        if ((pch = strchr(sz, ';')))
+            *pch = 0;
+    }
     if (sz)
         pMat->shine = atoi(sz);
     else
         pMat->shine = 128;
 
-    if (sz)
+    if (sz) {
         sz += strlen(sz) + 1;
-    if ((pch = strchr(sz, ';')))
-        *pch = 0;
+        if ((pch = strchr(sz, ';')))
+            *pch = 0;
+    }
     if (sz) {
         int o = atoi(sz);
         if (o == 100)
@@ -243,7 +244,7 @@ SetMaterialDice(Material * pMat, const char *sz, int *flag)
 
 /* Set colour, alpha, refraction, shine, specular. */
 static int
-SetColourARSS(double aarColour[2][4],
+SetColourARSS(float aarColour[2][4],
               float arRefraction[2], float arCoefficient[2], float arExponent[2], char *sz, int i)
 {
 
@@ -256,7 +257,7 @@ SetColourARSS(double aarColour[2][4],
 
         if (pch) {
             /* alpha */
-            aarColour[i][3] = g_ascii_strtod(pch, NULL);
+            aarColour[i][3] = (float) g_ascii_strtod(pch, NULL);
 
             if ((pch = strchr(pch, ';')))
                 *pch++ = 0;
@@ -265,7 +266,7 @@ SetColourARSS(double aarColour[2][4],
 
         if (pch) {
             /* refraction */
-            arRefraction[i] = g_ascii_strtod(pch, NULL);
+            arRefraction[i] = (float) g_ascii_strtod(pch, NULL);
 
             if ((pch = strchr(pch, ';')))
                 *pch++ = 0;
@@ -274,7 +275,7 @@ SetColourARSS(double aarColour[2][4],
 
         if (pch) {
             /* shine */
-            arCoefficient[i] = g_ascii_strtod(pch, NULL);
+            arCoefficient[i] = (float) g_ascii_strtod(pch, NULL);
 
             if ((pch = strchr(pch, ';')))
                 *pch++ = 0;
@@ -283,7 +284,7 @@ SetColourARSS(double aarColour[2][4],
 
         if (pch) {
             /* specular */
-            arExponent[i] = g_ascii_strtod(pch, NULL);
+            arExponent[i] = (float) g_ascii_strtod(pch, NULL);
 
             if ((pch = strchr(pch, ';')))
                 *pch++ = 0;
@@ -298,7 +299,7 @@ SetColourARSS(double aarColour[2][4],
 
 /* Set colour, shine, specular, flag. */
 static int
-SetColourSSF(gdouble aarColour[2][4],
+SetColourSSF(float aarColour[2][4],
              gfloat arCoefficient[2], gfloat arExponent[2], int afDieColour[2], char *sz, int i)
 {
 
@@ -347,7 +348,7 @@ SetWood(const char *sz, woodtype * pbw)
 {
 
     woodtype bw;
-    int cch = strlen(sz);
+    size_t cch = strlen(sz);
 
     for (bw = 0; bw <= WOOD_PAINT; bw++)
         if (!StrNCaseCmp(sz, aszWoodName[bw], cch)) {
@@ -372,7 +373,8 @@ check_for_board3d(char *szValue)
 extern void
 RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue)
 {
-    int c, fValueError = FALSE;
+    size_t c;
+    int fValueError = FALSE;
 
     if (!szParam || !*szParam)
         return;
@@ -467,23 +469,23 @@ RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue)
         float rAzimuth, rElevation;
         gchar **split = g_strsplit(szValue, ";", 0);
 
-        rAzimuth = (float) g_ascii_strtod(split[0], NULL);
-        rElevation = (float) g_ascii_strtod(split[1], NULL);
+        rAzimuth = (float) (g_ascii_strtod(split[0], NULL) * G_PI / 180.0);
+        rElevation = (float) (g_ascii_strtod(split[1], NULL) * G_PI / 180.0);
 
         g_strfreev(split);
 
         if (rElevation < 0.0f)
             rElevation = 0.0f;
-        else if (rElevation > 90.0f)
-            rElevation = 90.0f;
+        else if (rElevation > (float) G_PI_2)
+            rElevation = (float) G_PI_2;
 
-        prd->arLight[2] = sinf(rElevation / 180 * G_PI);
-        prd->arLight[0] = cosf(rAzimuth / 180 * G_PI) * sqrt(1.0 - prd->arLight[2] * prd->arLight[2]);
-        prd->arLight[1] = sinf(rAzimuth / 180 * G_PI) * sqrt(1.0 - prd->arLight[2] * prd->arLight[2]);
+        prd->arLight[2] = sinf(rElevation);
+        prd->arLight[0] = cosf(rAzimuth) * sqrtf(1.0f - prd->arLight[2] * prd->arLight[2]);
+        prd->arLight[1] = sinf(rAzimuth) * sqrtf(1.0f - prd->arLight[2] * prd->arLight[2]);
     } else if (!StrNCaseCmp(szParam, "shape", c)) {
         float rRound = (float) g_ascii_strtod(szValue, &szValue);
 
-        prd->rRound = 1.0 - rRound;
+        prd->rRound = 1.0f - rRound;
     } else if (!StrNCaseCmp(szParam, "moveindicator", c))
         prd->showMoveIndicator = toupper(*szValue) == 'Y';
 #if USE_BOARD3D
@@ -641,8 +643,8 @@ SaveRenderingSettings(FILE * pf)
     gchar buf3[G_ASCII_DTOSTR_BUF_SIZE];
     renderdata *prd = GetMainAppearance();
     float rElevation = (float) (asinf(prd->arLight[2]) * 180 / G_PI);
-    float rAzimuth = (fabs(prd->arLight[2] - 1.0f) < 1e-5) ? 0.0f :
-        (float) (acosf(prd->arLight[0] / sqrt(1.0 - prd->arLight[2] * prd->arLight[2])) * 180 / G_PI);
+    float rAzimuth = (fabsf(prd->arLight[2] - 1.0f) < 1e-5f) ? 0.0f :
+        (float) (acosf(prd->arLight[0] / sqrtf(1.0f - prd->arLight[2] * prd->arLight[2])) * 180 / G_PI);
 
     if (prd->arLight[1] < 0)
         rAzimuth = 360 - rAzimuth;
@@ -664,7 +666,7 @@ SaveRenderingSettings(FILE * pf)
     fprintf(pf, "animateflag=%c ", prd->animateFlag ? 'y' : 'n');
     fprintf(pf, "closeboard=%c ", prd->closeBoardOnExit ? 'y' : 'n');
     fprintf(pf, "quickdraw=%c ", prd->quickDraw ? 'y' : 'n');
-    fprintf(pf, "curveaccuracy=%d ", prd->curveAccuracy);
+    fprintf(pf, "curveaccuracy=%u ", prd->curveAccuracy);
     fprintf(pf, "lighttype=%c ", prd->lightType == LT_POSITIONAL ? 'p' : 'd');
 
     g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%f", prd->lightPos[0]);
