@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: sgf.c,v 1.150 2013/07/06 21:30:03 plm Exp $
+ * $Id: sgf.c,v 1.155 2015/02/01 18:11:53 plm Exp $
  */
 
 #include "config.h"
@@ -43,7 +43,7 @@
 static const char *szFile;
 static int fError;
 
-static int CheckSGFVersion(const char **sz);
+static int CheckSGFVersion(char **sz);
 static void
 ErrorHandler(const char *sz, int UNUSED(fParseError))
 {
@@ -583,7 +583,7 @@ RestoreEvalContext(evalcontext * pec, char *pc)
 
     int fUsePrune = 0;
     int red __attribute((unused)) = 0;
-    int ver = CheckSGFVersion((const char **) &pc);
+    int ver = CheckSGFVersion(&pc);
 
     InitEvalContext(pec);
     pec->nPlies = (unsigned int)strtol(pc, &pc, 10);
@@ -647,7 +647,7 @@ RestoreRolloutRolloutContext(rolloutcontext * prc, const char *sz)
     prc->fStopOnSTD = 0;
     prc->nLate = 0;
     prc->nMinimumGames = 144;
-    prc->rStdLimit = 0.01;
+    prc->rStdLimit = 0.01f;
 
     if (!pc)
         return;
@@ -729,7 +729,7 @@ RestoreRolloutInternals(evalsetup * pes, const char *sz)
 }
 
 static int
-CheckSGFVersion(const char **sz)
+CheckSGFVersion(char **sz)
 {
 
     int n;
@@ -799,7 +799,7 @@ RestoreExtendedRolloutContext(rolloutcontext * prc, const char *sz)
     prc->fTruncBearoffOS = fTruncBearoffOS;
     prc->rngRollout = RNG_MERSENNE;
     prc->nMinimumGames = 144;
-    prc->rStdLimit = 0.01;
+    prc->rStdLimit = 0.01f;
 
     for (i = 0; i < 2; ++i) {
         sprintf(szTemp, "latecube%d ", i);
@@ -823,7 +823,7 @@ RestoreExtendedRolloutContext(rolloutcontext * prc, const char *sz)
 }
 
 static void
-RestoreExtendedCubeRollout(const char *sz,
+RestoreExtendedCubeRollout(char *sz,
                            float aarOutput[][NUM_ROLLOUT_OUTPUTS],
                            float aarStdDev[][NUM_ROLLOUT_OUTPUTS], evalsetup * pes)
 {
@@ -840,7 +840,7 @@ RestoreExtendedCubeRollout(const char *sz,
 }
 
 static void
-RestoreExtendedRollout(move * pm, const char *sz)
+RestoreExtendedRollout(move * pm, char *sz)
 {
 
     evalsetup *pes = &pm->esMove;
@@ -877,7 +877,7 @@ RestoreDoubleAnalysis(property * pp,
         /* EVAL_EVAL */
         ++pch;
         pes->et = EVAL_EVAL;
-        ver = CheckSGFVersion((const char **) &pch);
+        ver = CheckSGFVersion(&pch);
         nReduced = 0;
         pes->ec.rNoise = 0.0f;
         memset(aarOutput[0], 0, NUM_ROLLOUT_OUTPUTS * sizeof(float));
@@ -1016,7 +1016,7 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
 
         switch (ch) {
         case 'E':
-            ver = CheckSGFVersion((const char **) &pch);
+            ver = CheckSGFVersion(&pch);
             /* EVAL_EVAL */
             pm->esMove.et = EVAL_EVAL;
             nReduced = 0;
@@ -1611,7 +1611,7 @@ WriteEvalContext(FILE * pf, const evalcontext * pec)
 {
     gchar buffer[G_ASCII_DTOSTR_BUF_SIZE];
     g_ascii_formatd(buffer, sizeof(buffer), "%.6f", pec->rNoise);
-    fprintf(pf, "ver %d %d%s %d %s %d",
+    fprintf(pf, "ver %d %u%s %u %s %u",
             SGF_FORMAT_VER, pec->nPlies, pec->fCubeful ? "C" : "", pec->fDeterministic, buffer, pec->fUsePrune);
 }
 
@@ -1628,12 +1628,12 @@ WriteMoveFilters(FILE * pf, movefilter mf[MAX_FILTER_PLIES][MAX_FILTER_PLIES], i
 }
 
 static void
-WriteRolloutContext(FILE * pf, const rolloutcontext * prc)
+WriteRolloutContext(FILE * pf, rolloutcontext * prc)
 {
 
     int i;
 
-    fprintf(pf, "RC %d %d %d %d %d %d %d %d %d %d \"%s\" %lu ",
+    fprintf(pf, "RC %u %u %u %u %u %u %d %u %u %d \"%s\" %lu ",
             prc->fCubeful,
             prc->fVarRedn,
             prc->fInitial,
@@ -1651,7 +1651,7 @@ WriteRolloutContext(FILE * pf, const rolloutcontext * prc)
         WriteEvalContext(pf, &prc->aecChequer[i]);
         if (prc->aecChequer[i].nPlies) {
             fprintf(pf, " filt%d ", i);
-            WriteMoveFilters(pf, (movefilter(*)[4]) prc->aaamfChequer[i], prc->aecChequer[i].nPlies);
+            WriteMoveFilters(pf, prc->aaamfChequer[i], prc->aecChequer[i].nPlies);
         }
     }
 
@@ -1664,7 +1664,7 @@ WriteRolloutContext(FILE * pf, const rolloutcontext * prc)
         WriteEvalContext(pf, &prc->aecChequerLate[i]);
         if (prc->aecChequerLate[i].nPlies) {
             fprintf(pf, " latefilt%d ", i);
-            WriteMoveFilters(pf, (movefilter(*)[4]) prc->aaamfLate[i], prc->aecChequerLate[i].nPlies);
+            WriteMoveFilters(pf, prc->aaamfLate[i], prc->aecChequerLate[i].nPlies);
         }
     }
 
@@ -1699,7 +1699,7 @@ WriteRolloutAnalysis(FILE * pf, int fIsMove,
         fprintf(pf, "X ver %d Eq ", SGF_FORMAT_VER);
     }
 
-    fprintf(pf, "Trials %d ", pes->rc.nGamesDone);
+    fprintf(pf, "Trials %u ", pes->rc.nGamesDone);
     if (!fIsMove)
         fprintf(pf, "NoDouble ");
 
@@ -1747,7 +1747,7 @@ WriteDoubleAnalysis(FILE * pf,
     switch (pes->et) {
     case EVAL_EVAL:
         g_ascii_formatd(buffer, sizeof(buffer), "%.6f", pes->ec.rNoise);
-        fprintf(pf, "E ver %d %d%s %d %s %d",
+        fprintf(pf, "E ver %d %u%s %u %s %u",
                 SGF_FORMAT_VER,
                 pes->ec.nPlies, pes->ec.fCubeful ? "C" : "", pes->ec.fDeterministic, buffer, pes->ec.fUsePrune);
 
@@ -1829,7 +1829,7 @@ WriteMoveAnalysis(FILE * pf, int fPlayer, movelist * pml, unsigned int iMove)
             g_ascii_formatd(buffer, sizeof(buffer), "%.6f", pml->amMoves[i].rScore);
             fprintf(pf, "%s ", buffer);
             g_ascii_formatd(buffer, sizeof(buffer), "%.6f", pml->amMoves[i].esMove.ec.rNoise);
-            fprintf(pf, "%d%s %d %d %s %d",
+            fprintf(pf, "%u%s %d %u %s %u",
                     pml->amMoves[i].esMove.ec.nPlies,
                     pml->amMoves[i].esMove.ec.fCubeful ? "C" : "",
                     0, pml->amMoves[i].esMove.ec.fDeterministic, buffer, pml->amMoves[i].esMove.ec.fUsePrune);
@@ -2096,7 +2096,7 @@ SaveGame(FILE * pf, listOLD * plGame)
         WriteProperty(pf, "WR", mi.pchRating[0]);
         WriteProperty(pf, "BR", mi.pchRating[1]);
         if (mi.nYear) {
-            sprintf(szDate, "%04d-%02d-%02d", mi.nYear, mi.nMonth, mi.nDay);
+            sprintf(szDate, "%04u-%02u-%02u", mi.nYear, mi.nMonth, mi.nDay);
             WriteProperty(pf, "DT", szDate);
         }
         WriteProperty(pf, "EV", mi.pchEvent);
@@ -2153,7 +2153,7 @@ SaveGame(FILE * pf, listOLD * plGame)
                 memcpy(pmr->n.anMove, pmr->ml.amMoves[0].anMove, sizeof(pmr->n.anMove));
                 pmr->n.iMove = 0;
             }
-            fprintf(pf, "\n;%c[%d%d", pmr->fPlayer ? 'B' : 'W', pmr->anDice[0], pmr->anDice[1]);
+            fprintf(pf, "\n;%c[%u%u", pmr->fPlayer ? 'B' : 'W', pmr->anDice[0], pmr->anDice[1]);
             WriteMove(pf, pmr->fPlayer, pmr->n.anMove);
             putc(']', pf);
 
@@ -2259,7 +2259,7 @@ SaveGame(FILE * pf, listOLD * plGame)
             break;
 
         case MOVE_SETDICE:
-            fprintf(pf, "\n;PL[%c]DI[%d%d]", pmr->fPlayer ? 'B' : 'W', pmr->anDice[0], pmr->anDice[1]);
+            fprintf(pf, "\n;PL[%c]DI[%u%u]", pmr->fPlayer ? 'B' : 'W', pmr->anDice[0], pmr->anDice[1]);
 
             WriteLuck(pf, pmr->fPlayer, pmr->rLuck, pmr->lt);
 
