@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: show.c,v 1.271 2013/06/16 02:16:20 mdpetch Exp $
+ * $Id: show.c,v 1.284 2015/02/09 21:55:33 plm Exp $
  */
 
 #include "config.h"
@@ -45,6 +45,8 @@
 #include "boarddim.h"
 #include "credits.h"
 #include "util.h"
+#include "openurl.h"
+#include "multithread.h"
 
 #if USE_GTK
 #include "gtkboard.h"
@@ -56,11 +58,7 @@
 #include "gtkrolls.h"
 #include "gtktempmap.h"
 #include "gtkoptions.h"
-#else
-#include <glib.h>
 #endif
-#include "openurl.h"
-#include "multithread.h"
 
 #ifdef WIN32
 #include <io.h>
@@ -120,13 +118,11 @@ ShowEvaluation(const evalcontext * pec)
             (pec->fUsePrune) ? _("Using pruning neural nets.") :
             _("Not using pruning neural nets."), pec->fCubeful ? _("Cubeful") : _("Cubeless"));
 
-    if (pec->rNoise)
+    if (pec->rNoise > 0.0f) {
         outputf("%s%s %5.3f", ("        "), _("Noise standard deviation"), pec->rNoise);
-    else
-        outputf("%s%s", "        ", _("Noiseless evaluations"));
-
-    outputl(pec->fDeterministic ? _(" (deterministic noise).\n") : _(" (pseudo-random noise).\n"));
-
+        outputl(pec->fDeterministic ? _(" (deterministic noise).\n") : _(" (pseudo-random noise).\n"));
+    } else
+        outputf("%s%s", "        ", _("Noiseless evaluations.\n"));
 }
 
 extern int
@@ -139,7 +135,7 @@ EvalCmp(const evalcontext * E1, const evalcontext * E2, const int nElements)
         return 0;
 
     for (i = 0; i < nElements; ++i, ++E1, ++E2) {
-        cmp = memcmp((void *) E1, (void *) E2, sizeof(evalcontext));
+        cmp = memcmp((const void *) E1, (const void *) E2, sizeof(evalcontext));
         if (cmp != 0)
             break;
     }
@@ -191,7 +187,7 @@ static void
 show_movefilters(movefilter aaamf[2][MAX_FILTER_PLIES][MAX_FILTER_PLIES])
 {
 
-    if (equal_movefilters((movefilter(*)[MAX_FILTER_PLIES]) aaamf[0], (movefilter(*)[MAX_FILTER_PLIES]) aaamf[1]))
+    if (equal_movefilters(aaamf[0], aaamf[1]))
         ShowMoveFilters(aaamf[0]);
     else {
         int i;
@@ -203,7 +199,7 @@ show_movefilters(movefilter aaamf[2][MAX_FILTER_PLIES][MAX_FILTER_PLIES])
 }
 
 static void
-ShowRollout(const rolloutcontext * prc)
+ShowRollout(rolloutcontext * prc)
 {
 
     int fDoTruncate = 0;
@@ -275,12 +271,12 @@ ShowRollout(const rolloutcontext * prc)
 
     if (fLateEvals) {
         outputf(_("Move filter for first %d plies:\n"), nLate);
-        show_movefilters((movefilter(*)[4][4]) prc->aaamfChequer);
+        show_movefilters(prc->aaamfChequer);
         outputf(_("Move filter after %d plies:\n"), nLate);
-        show_movefilters((movefilter(*)[4][4]) prc->aaamfLate);
+        show_movefilters(prc->aaamfLate);
     } else {
         outputf(_("Move filter:\n"));
-        show_movefilters((movefilter(*)[4][4]) prc->aaamfChequer);
+        show_movefilters(prc->aaamfChequer);
     }
 
     if (fDoTruncate) {
@@ -299,7 +295,7 @@ ShowRollout(const rolloutcontext * prc)
 }
 
 static void
-ShowEvalSetup(const evalsetup * pes)
+ShowEvalSetup(evalsetup * pes)
 {
 
     switch (pes->et) {
@@ -515,21 +511,32 @@ CommandShowDelay(char *UNUSED(sz))
 #endif
 }
 
+extern void
+CommandShowAliases(char *UNUSED(sz))
+{
+    outputf(_("Aliases for player 1 when importing MAT files is set to \"%s\".\n "), player1aliases);
+}
+
 extern void
 CommandShowCache(char *UNUSED(sz))
 {
+    unsigned int c[2], cHit[2], cLookup[2];
 
-    unsigned int c, cHit;
-    unsigned int cLookup;
+    EvalCacheStats(c, cLookup, cHit);
 
-    EvalCacheStats(&c, &cLookup, &cHit);
+    outputf("%10u regular eval entries used %10u lookups %10u hits", c[0], cLookup[0], cHit[0]);
 
-    outputf(_("%d cache entries have been used.  %d lookups, %d hits"), c, cLookup, cHit);
+    if (cLookup[0])
+        outputf(" (%4.1f%%).", (float) cHit[0] * 100.0f / (float) cLookup[0]);
+    else
+        outputc('.');
 
-    if (cLookup > 0x01000000)   /* calculate carefully to avoid overflow */
-        outputf(" (%d%%).", (cHit + (cLookup / 200)) / (cLookup / 100));
-    else if (cLookup)
-        outputf(" (%d%%).", (cHit * 100 + cLookup / 2) / cLookup);
+    outputc('\n');
+
+    outputf("%10u pruning eval entries used %10u lookups %10u hits", c[1], cLookup[1], cHit[1]);
+
+    if (cLookup[1])
+        outputf(" (%4.1f%%).", (float) cHit[1] * 100.0f / (float) cLookup[1]);
     else
         outputc('.');
 
@@ -1519,43 +1526,43 @@ CommandShowMarketWindow(char *sz)
 
     /* see if ratios are given on command line */
 
-    aarRates[0][0] = (float) ParseReal(&sz);
+    aarRates[0][0] = ParseReal(&sz);
 
     if (aarRates[0][0] >= 0) {
 
         /* read the others */
 
-        aarRates[1][0] = ((r = (float) ParseReal(&sz)) > 0.0f) ? r : 0.0f;
-        aarRates[0][1] = ((r = (float) ParseReal(&sz)) > 0.0f) ? r : 0.0f;
-        aarRates[1][1] = ((r = (float) ParseReal(&sz)) > 0.0f) ? r : 0.0f;
+        aarRates[1][0] = ((r = ParseReal(&sz)) > 0.0f) ? r : 0.0f;
+        aarRates[0][1] = ((r = ParseReal(&sz)) > 0.0f) ? r : 0.0f;
+        aarRates[1][1] = ((r = ParseReal(&sz)) > 0.0f) ? r : 0.0f;
 
         /* If one of the ratios are larger than 1 we assume the user
          * has entered 25.1 instead of 0.251 */
 
-        if (aarRates[0][0] > 1.0 || aarRates[1][0] > 1.0 || aarRates[0][1] > 1.0 || aarRates[1][1] > 1.0) {
-            aarRates[0][0] /= 100.0;
-            aarRates[1][0] /= 100.0;
-            aarRates[0][1] /= 100.0;
-            aarRates[1][1] /= 100.0;
+        if (aarRates[0][0] > 1.0f || aarRates[1][0] > 1.0f || aarRates[0][1] > 1.0f || aarRates[1][1] > 1.0f) {
+            aarRates[0][0] /= 100.0f;
+            aarRates[1][0] /= 100.0f;
+            aarRates[0][1] /= 100.0f;
+            aarRates[1][1] /= 100.0f;
         }
 
         /* Check that ratios are 0 <= ratio <= 1 */
 
         for (i = 0; i < 2; i++) {
-            if (aarRates[i][0] > 1.0) {
+            if (aarRates[i][0] > 1.0f) {
                 outputf(_("illegal gammon ratio for player %i: %f\n"), i, aarRates[i][0]);
                 return;
             }
-            if (aarRates[i][1] > 1.0) {
+            if (aarRates[i][1] > 1.0f) {
                 outputf(_("illegal backgammon ratio for player %i: %f\n"), i, aarRates[i][1]);
                 return;
             }
         }
 
-        /* Transfer rations to arOutput
+        /* Transfer ratios to arOutput
          * (used in call to GetPoints below) */
 
-        arOutput[OUTPUT_WIN] = 0.5;
+        arOutput[OUTPUT_WIN] = 0.5f;
         arOutput[OUTPUT_WINGAMMON] = (aarRates[ms.fMove][0] + aarRates[ms.fMove][1]) * 0.5f;
         arOutput[OUTPUT_LOSEGAMMON] = (aarRates[!ms.fMove][0] + aarRates[!ms.fMove][1]) * 0.5f;
         arOutput[OUTPUT_WINBACKGAMMON] = aarRates[ms.fMove][1] * 0.5f;
@@ -1785,7 +1792,7 @@ CommandShowExport(char *UNUSED(sz))
     output(_("\n"
              "Export settings: \n\n"
              "WARNING: not all settings are honoured in the export!\n"
-             "         Do not expect to much!\n\n" "Include: \n\n"));
+             "         Do not expect too much!\n\n" "Include: \n\n"));
 
     output(_("- annotations"));
     outputf("\r\t\t\t\t\t\t: %s\n", exsExport.fIncludeAnnotation ? _("yes") : _("no"));
@@ -1886,7 +1893,7 @@ CommandShowExport(char *UNUSED(sz))
     outputf(_("- URL to pictures used in export\n"
               "\t%s\n"), exsExport.szHTMLPictureURL ? exsExport.szHTMLPictureURL : _("not defined"));
 
-    outputf(_("- size of exported Html pictures: %dx%d\n"),
+    outputf(_("- size of exported HTML pictures: %dx%d\n"),
             exsExport.nHtmlSize * BOARD_WIDTH, exsExport.nHtmlSize * BOARD_HEIGHT);
 
     /* PNG options */
@@ -2025,7 +2032,7 @@ CommandShowTemperatureMap(char *sz)
                     FormatCubePosition(asz[i], &ci);
                 }
 
-                GTKShowTempMap(ams, 2, (const gchar **) asz, FALSE);
+                GTKShowTempMap(ams, 2, asz, FALSE);
 
                 for (i = 0; i < 2; ++i)
                     g_free(asz[i]);
@@ -2070,6 +2077,12 @@ CommandShowCheat(char *UNUSED(sz))
 
 }
 
+extern void
+CommandShowRatingOffset(char *UNUSED(sz))
+{
+    outputf(_("The rating offset for estimating absolute ratings is: %.1f\n"), rRatingOffset);
+}
+
 
 extern void
 CommandShowCubeEfficiency(char *UNUSED(sz))
