@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: text.c,v 1.108 2013/06/16 02:16:21 mdpetch Exp $
+ * $Id: text.c,v 1.109 2014/02/12 21:13:53 plm Exp $
  */
 
 #include "config.h"
@@ -123,7 +123,7 @@ printTextBoard(FILE * pf, const matchstate * pms)
 
     PipCount((ConstTanBoard) anBoard, anPips);
 
-    fprintf(pf, "Pip counts: O %d, X %d\n\n", anPips[0], anPips[1]);
+    fprintf(pf, "Pip counts: O %u, X %u\n\n", anPips[0], anPips[1]);
 
 }
 
@@ -223,7 +223,7 @@ TextEpilogue(FILE * pf, const matchstate * UNUSED(pms))
 
     time_t t;
 
-    const char szVersion[] = "$Revision: 1.108 $";
+    const char szVersion[] = "$Revision: 1.109 $";
     int iMajor, iMinor;
 
     iMajor = atoi(strchr(szVersion, ' '));
